/************************************************************************************/
/*  Copyright (C)           Microcyber Inc. All Rights Reserved                     */
/*  Product:                NCS-TT105 Profibus PA                                   */
/*                                                                                  */
/*  Device:                 NCS-TT105 TEMPERATURE DEVICE for PROFIBUS PA            */
/*  Description:            Device Description File                                 */
/*  Dictionary:             SIPADC01.dct                                            */
/*                                                                                  */
/*  Revision:  1.0                                                                  */
/*  Date:      2008-06-23                                                           */
/*  Author:    Ning Dekui                                                           */
/************************************************************************************/
MANUFACTURER            0x16c,
DEVICE_TYPE             0x01,
DEVICE_REVISION         0x01,
DD_REVISION             0x01

#define _NCS_TT
#define _REV2
#define DEVICE_TYPE "NCS_TT105"

#include "SI_FileM.inc"
#include "SI_HlpM.inc"
#include "SI_OptM.inc"
#include "SIPAST_CommError.inc"

/*
#include "SI_MainMenu.inc"
#include "SI_ViewM.inc"
*/

#include "defmacros.inc"
#include "Phys_Blk.inc"
#include "AI2_Blk1.inc"
#include "MC_YT.inc" 



/***********************************************************************/
/*    Transducer Block 1                                               */
/***********************************************************************/

BLOCK trans1_TT_1
{
    TYPE    TRANSDUCER;
    NUMBER    1;
}

trans1_TT_1_blk_reserve                            LIKE VARIABLE    phys_blk_reserve
{
}

VARIABLE trans1_TT_1_blk_object
{
    LABEL       [blk_block_object];
    HELP        [blk_block_object_help];
    CLASS       DEVICE;
    HANDLING    READ;
    TYPE        ENUMERATED(1)
    {
        {    3,    [blk_block_object_TRANSDUCER]        }
    }
}

VARIABLE trans1_TT_1_blk_parent_class
{
    LABEL       [blk_parent_class];
    HELP        [trans_blk_parent_class_help];
    CLASS       DEVICE;
    HANDLING    READ;
    TYPE        ENUMERATED(1)
    {
        {    2,    [trans_blk_parent_class_TEMP]    }
    }
}

VARIABLE trans1_TT_1_blk_class
{
    LABEL       [blk_class];
    HELP        [trans_blk_class_help];
    CLASS       DEVICE;
    HANDLING    READ;
    TYPE        ENUMERATED(1)
    {
        DEFAULT_VALUE    18;
        {    1,      [trans_temp_blk_class_TC]     },
        {    2,      [trans_temp_blk_class_RTD]    },
        {    3,      [trans_temp_blk_class_PYR]    },
        {    16,     "TC + DC U"                   },
        {    17,     "RTD + R"                     },
        {    18,     "TC + RTD + R + DC U"         },
        {    250,    [not_used]                    },
        {    251,    [none]                        },
        {    252,    [unknown]                     },
        {    253,    [special]                     }
    }
}

trans1_TT_1_blk_dd_reference                      LIKE VARIABLE    phys_blk_dd_reference
{
}

trans1_TT_1_blk_dd_rev                            LIKE VARIABLE    phys_blk_dd_rev
{
}

trans1_TT_1_blk_profile                           LIKE VARIABLE    phys_blk_profile
{
}

trans1_TT_1_blk_profile_rev                       LIKE VARIABLE    phys_blk_profile_rev
{
}

trans1_TT_1_blk_execution_time                    LIKE VARIABLE    phys_blk_execution_time
{
}

trans1_TT_1_blk_num_parameters                    LIKE VARIABLE    phys_blk_num_parameters
{
}

trans1_TT_1_blk_index_view_1                      LIKE VARIABLE    phys_blk_index_view_1
{
}

trans1_TT_1_blk_num_view_lists                    LIKE VARIABLE    phys_blk_num_view_lists
{
}

trans1_TT_1_st_rev                                LIKE VARIABLE    phys_st_rev
{
}

trans1_TT_1_tag_desc                              LIKE VARIABLE    phys_tag_desc
{
    REDEFINE LABEL        [MC_trans1_tag_desc];        
}

trans1_TT_1_strategy                              LIKE VARIABLE    phys_strategy
{
}

trans1_TT_1_alert_key                             LIKE VARIABLE    phys_alert_key
{
}

trans1_TT_1_target_mode                           LIKE VARIABLE    phys_target_mode
{
}

trans1_TT_1_actual_mode                           LIKE VARIABLE    phys_actual_mode
{
}

trans1_TT_1_permitted_mode                        LIKE VARIABLE    phys_permitted_mode
{
}

trans1_TT_1_normal_mode                           LIKE VARIABLE    phys_normal_mode
{
}

trans1_TT_1_current_state_alarm_sum               LIKE VARIABLE    phys_current_state_alarm_sum
{
}

trans1_TT_1_unacknowledged_state_alarm_sum        LIKE VARIABLE    phys_unacknowledged_state_alarm_sum
{
}

trans1_TT_1_unreported_state_alarm_sum            LIKE VARIABLE    phys_unreported_state_alarm_sum
{
}

trans1_TT_1_disabled_state_alarm_sum              LIKE VARIABLE    phys_disabled_state_alarm_sum
{
}


/*---------------------------------------------------------------------*/
/*    Transducer Block: Temperature Transmitter                        */
/*---------------------------------------------------------------------*/

VARIABLE trans1_TT_1_lin_type             /* index 14 */
{
    LABEL       [trans_lin_type];
    HELP        [trans_lin_type_help];
    CLASS       DEVICE;
    HANDLING    READ & WRITE;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    102;
        { 0,      [linear]           },
        { 102,    [RTD_Pt100]        },
        { 105,    [RTD_Pt1000]       },
        { 240,    [MC_RTD_Cu50]      },
        { 127,    [RTD_Cu100]        },

        { 128,    [TC_type_B]        },
        { 131,    [TC_type_E]        },
        { 133,    [TC_type_J]        },
        { 134,    [TC_type_K]        },
        { 135,    [TC_type_N]        },
        { 136,    [TC_type_R]        },
        { 137,    [TC_type_S]        },
        { 138,    [TC_type_T]        }
    }
    POST_EDIT_ACTIONS
    {
        method_tt_1_lin_type
    }
}

VARIABLE trans1_TT_1_primary_value
{
    LABEL       [trans_value];
    HELP        [trans_temp_value_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    CONSTANT_UNIT SELECT (trans1_TT_1_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1243];CASE 1281: [unit_1281];}
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
    }
}

VARIABLE trans1_TT_1_primary_value_status_quality
{
    LABEL       [status_quality];
    HELP        [value_status_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        STATUS_OUTPUT_NO_RCAS
    }
}

trans1_TT_1_primary_value_status_limit            LIKE VARIABLE    trans1_TT_1_primary_value_status_quality
{
    REDEFINE LABEL       [status_limit];        
    REDEFINE TYPE        ENUMERATED (1)
    {
        STATUS_OUTPUT_LIMIT
    }
}

VARIABLE trans1_TT_1_primary_value_unit
{
    LABEL       [digital_units];
    HELP        [MC_digital_units_help];
    CLASS       DEVICE;
    HANDLING    READ & WRITE;
    TYPE        ENUMERATED (2)
    {
        IF (trans1_TT_1_lin_type==0 && trans1_TT_1_input_range==0)
        {
            { 1243, [unit_1243],    [unit_1243_help] }
        }
        ELSE
        {
            IF (trans1_TT_1_lin_type==0 && (trans1_TT_1_input_range==128 || trans1_TT_1_input_range==129))
            {
                { 1281, [unit_1281],    [unit_1281_help] }
            }
            ELSE
            {
                IF (trans1_TT_1_lin_type>0)
                {
                    { 1000, [unit_1000],    [unit_1000_help] },
                    { 1001, [unit_1001],    [unit_1001_help] },
                    { 1002, [unit_1002],    [unit_1002_help] },
                    { 1003, [unit_1003],    [unit_1003_help] }
                }
            }
        }
    }
    DEFAULT_VALUE IF (trans1_TT_1_lin_type == 0){1281;} ELSE {1001;}
    POST_EDIT_ACTIONS
    {
        method_TT_1_primary_value_unit
    }
    POST_WRITE_ACTIONS
    {
        method_TT_1_post_write_read_device_values
    }
}

VARIABLE trans1_TT_1_secondary_value_1
{
    LABEL       [trans_temp_secondary_value1];
    HELP        "Process temperature connected to channel 1 (T1).";
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    CONSTANT_UNIT SELECT (trans1_TT_1_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1243];CASE 1281: [unit_1281];}
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
    }
}

VARIABLE trans1_TT_1_secondary_value_1_status_quality
{
    LABEL       [status_quality];
    HELP        [value_status_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        STATUS_OUTPUT_NO_RCAS
    }
}

trans1_TT_1_secondary_value_1_status_limit        LIKE VARIABLE    trans1_TT_1_secondary_value_1_status_quality
{
    REDEFINE LABEL       [status_limit];        
    REDEFINE TYPE        ENUMERATED (1)
    {
        STATUS_OUTPUT_LIMIT
    }
}

VARIABLE trans1_TT_1_secondary_value_2
{
    LABEL       [trans_temp_secondary_value2];
    HELP        "Process temperature connected to channel 2 (T2).";
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    CONSTANT_UNIT SELECT (trans1_TT_1_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1243];CASE 1281: [unit_1281];}
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
    }
}

VARIABLE trans1_TT_1_secondary_value_2_status_quality
{
    LABEL       [status_quality];
    HELP        [value_status_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        STATUS_OUTPUT_NO_RCAS
    }
}

trans1_TT_1_secondary_value_2_status_limit            LIKE VARIABLE    trans1_TT_1_secondary_value_2_status_quality
{
    REDEFINE LABEL       [status_limit];        
    REDEFINE TYPE        ENUMERATED (1)
    {
        STATUS_OUTPUT_LIMIT
    }
}

VARIABLE trans1_TT_1_sensor_measure_type
{
    LABEL       [trans_temp_sensor_measure_type];
    HELP        [trans_temp_sensor_measure_type_help];
    CLASS       DEVICE;
    HANDLING    READ & WRITE;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE  0;
        {   0,      "PV=SV1"  },
        /*{   1,      "PV=SV2"  },*/
        IF (trans1_TT_1_primary_value_unit == trans1_TT_2_primary_value_unit)
        {
            {   128,    "PV=SV1-SV2"  },
            {   129,    "PV=SV2-SV1"  },
            {   192,    "PV=0.5x(SV1+SV2)"}
        }
    }
}

VARIABLE trans1_TT_1_input_range
{
    LABEL       [trans_temp_input_range];
    HELP        [trans_temp_input_range_help];
    CLASS       DEVICE;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    128;
        {    0,      [MC_100MV]          },
        {    128,    [MC_500Ohm]         },
        {    129,    [MC_4000Ohm]        }
    }
    HANDLING    IF (trans1_TT_1_lin_type == 0)
                {   
                    READ & WRITE;
                }
                ELSE
                {
                    READ;
                }
    POST_EDIT_ACTIONS
    {
        method_tt_1_input_range
    }
}

VARIABLE trans1_TT_1_bias_1
{
    LABEL       [trans_temp_bias_1];
    HELP        [trans_temp_bias_1_help];
    CLASS       DEVICE;
    CONSTANT_UNIT SELECT (trans1_TT_1_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1243];CASE 1281: [unit_1281];}
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    0.0;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_TT_1_bias_2
{
    LABEL       [trans_temp_bias_2];
    HELP        [trans_temp_bias_2_help];
    CLASS       DEVICE;
    CONSTANT_UNIT SELECT (trans1_TT_1_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1243];CASE 1281: [unit_1281];}
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    0.0;
    }
    HANDLING    IF (trans1_TT_1_sensor_measure_type == 0)
                {
                    READ;
                }
                ELSE
                {
                    READ & WRITE;
                }
}

VARIABLE trans1_TT_1_upper_sensor_limit
{
    LABEL       [trans_sensor_upper_limit];
    HELP        [trans_sensor_upper_limit_help];
    CLASS       DEVICE;
    CONSTANT_UNIT SELECT (trans1_TT_1_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1243];CASE 1281: [unit_1281];}
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    850.00;
    }
    HANDLING    READ;
}

VARIABLE trans1_TT_1_lower_sensor_limit
{
    LABEL       [trans_sensor_lower_limit];
    HELP        [trans_sensor_lower_limit_help];
    CLASS       DEVICE;
    CONSTANT_UNIT SELECT (trans1_TT_1_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1243];CASE 1281: [unit_1281];}
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    -200.00;
    }
    HANDLING    READ;
}

VARIABLE trans1_TT_1_input_fault_gen
{
    LABEL       [trans_temp_input_fault];
    HELP        [trans_temp_input_fault_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    TYPE        BIT_ENUMERATED (1)
    {
        { 0x00,    [trans_temp_input_fault_OK]            },
        { 0x01,    [trans_temp_input_fault_RJ_ERR]        },
        { 0x02,    [trans_temp_input_fault_HW_ERR]        },
        { 0X40,    [MC_Comm_Err]                          }
    }
}

VARIABLE trans1_TT_1_input_fault_1
{
    LABEL       [trans_temp_input_fault_CH1_FAULT];
    HELP        [trans_temp_input_fault_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    TYPE        BIT_ENUMERATED (1)
    {
        { 0x00,    [trans_temp_input_fault_OK]                },
        /*{ 0x01,    [trans_temp_input_fault_UNDERRANGE]        },
        { 0x02,    [trans_temp_input_fault_OVERRANGE]        },*/
        { 0x04,    [trans_temp_input_fault_LEAD_BREAK]        },
        /*{ 0x08,    [trans_temp_input_fault_SHORT_CIRCUIT]    },*/
        { 0X40,    [MC_Comm_Err]                              }
    }
    STYLE       "MULTILINE 16 2" ;
}

VARIABLE trans1_TT_1_input_fault_2
{
    LABEL       [trans_temp_input_fault_CH2_FAULT];
    HELP        [trans_temp_input_fault_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    TYPE        BIT_ENUMERATED (1)
    {
        { 0x00,    [trans_temp_input_fault_OK]                },
        /*{ 0x01,    [trans_temp_input_fault_UNDERRANGE]        },
        { 0x02,    [trans_temp_input_fault_OVERRANGE]        },*/
        { 0x04,    [trans_temp_input_fault_LEAD_BREAK]        },
        /*{ 0x08,    [trans_temp_input_fault_SHORT_CIRCUIT]    },*/
        { 0X40,    [MC_Comm_Err]                              }
    }
    STYLE       "MULTILINE 16 2" ;
}

VARIABLE trans1_TT_1_external_rj_value
{
    LABEL       [trans_temp_external_rj_value];
    HELP        [trans_temp_external_rj_value_help];
    CLASS       DEVICE;
    HANDLING    READ & WRITE;
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
    }
}

VARIABLE trans1_TT_1_rj_temp
{
    LABEL       [trans_temp_rj_temp];
    HELP        [trans_temp_rj_temp_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    CONSTANT_UNIT SELECT (trans1_TT_1_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1001];CASE 1281: [unit_1001];}
    TYPE        FLOAT
    {
        DEFAULT_VALUE 0.0;
        DISPLAY_FORMAT ".2f";
//        MIN_VALUE SELECT (trans1_TT_1_primary_value_unit) {CASE 1000: 233.15;CASE 1001: -40.0;CASE 1002: -40.0;CASE 1003: 419.67;}
//        MAX_VALUE SELECT (trans1_TT_1_primary_value_unit) {CASE 1000: 385.15;CASE 1001: 85.0;CASE 1002: 185.0;CASE 1003: 644.67;}
    }
}

VARIABLE trans1_TT_1_rj_type
{
    LABEL       [trans_temp_rj_type];
    HELP        [trans_temp_rj_type_help];
    CLASS       DEVICE;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    1;
        {    0,        [MC_trans_temp_rj_type_NONE]   },
        {    1,        [MC_trans_temp_rj_type_INT]    }
    }
    HANDLING    IF ((trans1_TT_1_lin_type == 102) || (trans1_TT_1_lin_type == 105) || 
                    (trans1_TT_1_lin_type == 240) || (trans1_TT_1_lin_type == 127) ||
                    (trans1_TT_1_lin_type == 0))
                {
                    READ;
                }
                ELSE
                {
                    READ & WRITE;
                }
}

/*---------------------------------------------------------------------*/
/*    Transducer Block: Thermoresistance Temperature Device (RTD)       */
/*---------------------------------------------------------------------*/

VARIABLE trans1_TT_1_sensor_connection
{
    LABEL       [trans_temp_sensor_connection];
    HELP        [trans_temp_sensor_connection_help];
    CLASS       DEVICE;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    1;
        {    0,    [trans_temp_sensor_connection_2_WIRE]        },
        {    1,    [trans_temp_sensor_connection_3_WIRE]        }
    /*    {    2,    [trans_temp_sensor_connection_4_WIRE]        }  */
    }
    HANDLING    IF ((trans1_TT_1_lin_type == 102) || (trans1_TT_1_lin_type == 105) || 
                    (trans1_TT_1_lin_type == 240) || (trans1_TT_1_lin_type == 127) ||
                    (trans1_TT_1_lin_type == 0))
                {   
                    READ & WRITE;
                }
                ELSE
                {
                    READ;
                }
}

/*---------------------------------------------------------------------*/
/*    Transducer Block: user defined                                   */
/*---------------------------------------------------------------------*/
VARIABLE trans1_TT_1_Cal_Point_Hi
{
    LABEL       [trans_cal_point_hi];
    HELP        [trans_cal_point_hi_help];
    CLASS       DEVICE;
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    850.00;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_TT_1_Cal_Point_Lo
{
    LABEL       [trans_cal_point_lo];
    HELP        [trans_cal_point_lo_help];
    CLASS       DEVICE;
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    -200.00;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_TT_1_Cal_Min_Span
{
    LABEL       [trans_cal_min_span];
    HELP        [trans_cal_min_span_help];
    CLASS       DEVICE;
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    0.0;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_TT_1_Cal_Unit
{
    LABEL       [trans_cal_unit];
    HELP        [trans_cal_unit_help];
    CLASS       DEVICE;
    TYPE        ENUMERATED (2)
    {
        DEFAULT_VALUE    1001;
        { 1001, [unit_1001],    [unit_1001_help] },
        { 1243, [unit_1243],    [unit_1243_help] },
        { 1281, [unit_1281],    [unit_1281_help] }
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_TT_1_Sensor_Value_1
{
    LABEL       [MC_Sensor_Value_1];
    HELP        [MC_Sensor_Value_1];
    CLASS       DEVICE;
    HANDLING    READ;
    CONSTANT_UNIT SELECT (trans1_TT_1_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1243];CASE 1281: [unit_1281];}
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    0.0;
    }
}

VARIABLE trans1_TT_1_Sensor_Value_2
{
    LABEL       [MC_Sensor_Value_2];
    HELP        [MC_Sensor_Value_2];
    CLASS       DEVICE;
    HANDLING    READ;
    CONSTANT_UNIT SELECT (trans1_TT_1_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1243];CASE 1281: [unit_1281];}
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    0.0;
    }
}

VARIABLE trans1_TT_1_Two_Wires_Comp
{
    LABEL       [MC_two_wires_compe];
    HELP        [MC_two_wires_compe];
    CLASS       DEVICE;
    HANDLING    READ & WRITE;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    1;
        {    0,    "finished"    },
        {    1,    "Start"       }
    }
}



/***********************************************************************/
/*    Transducer Block 2                                               */
/***********************************************************************/

BLOCK trans1_TT_2
{
    TYPE    TRANSDUCER;
    NUMBER    2;
}

trans1_TT_2_blk_reserve                            LIKE VARIABLE    phys_blk_reserve
{
}

VARIABLE trans1_TT_2_blk_object
{
    LABEL       [blk_block_object];
    HELP        [blk_block_object_help];
    CLASS       DEVICE;
    HANDLING    READ;
    TYPE        ENUMERATED(1)
    {
        {    3,    [blk_block_object_TRANSDUCER]        }
    }
}

VARIABLE trans1_TT_2_blk_parent_class
{
    LABEL       [blk_parent_class];
    HELP        [trans_blk_parent_class_help];
    CLASS       DEVICE;
    HANDLING    READ;
    TYPE        ENUMERATED(1)
    {
        {    2,    [trans_blk_parent_class_TEMP]    }
    }
}

VARIABLE trans1_TT_2_blk_class
{
    LABEL       [blk_class];
    HELP        [trans_blk_class_help];
    CLASS       DEVICE;
    HANDLING    READ;
    TYPE        ENUMERATED(1)
    {
        DEFAULT_VALUE    18;
        {    1,        [trans_temp_blk_class_TC]     },
        {    2,        [trans_temp_blk_class_RTD]    },
        {    3,        [trans_temp_blk_class_PYR]    },
        {    16,       "TC + DC U"                   },
        {    17,       "RTD + R"                     },
        {    18,       "TC + RTD + R + DC U"         },
        {    250,      [not_used]                    },
        {    251,      [none]                        },
        {    252,      [unknown]                     },
        {    253,      [special]                     }
    }
}

trans1_TT_2_blk_dd_reference                      LIKE VARIABLE    phys_blk_dd_reference
{
}

trans1_TT_2_blk_dd_rev                            LIKE VARIABLE    phys_blk_dd_rev
{
}

trans1_TT_2_blk_profile                           LIKE VARIABLE    phys_blk_profile
{
}

trans1_TT_2_blk_profile_rev                       LIKE VARIABLE    phys_blk_profile_rev
{
}

trans1_TT_2_blk_execution_time                    LIKE VARIABLE    phys_blk_execution_time
{
}

trans1_TT_2_blk_num_parameters                    LIKE VARIABLE    phys_blk_num_parameters
{
}

trans1_TT_2_blk_index_view_1                      LIKE VARIABLE    phys_blk_index_view_1
{
}

trans1_TT_2_blk_num_view_lists                    LIKE VARIABLE    phys_blk_num_view_lists
{
}

trans1_TT_2_st_rev                                LIKE VARIABLE    phys_st_rev
{
}

trans1_TT_2_tag_desc                              LIKE VARIABLE    phys_tag_desc
{
    REDEFINE LABEL        [MC_trans2_tag_desc];        
}

trans1_TT_2_strategy                              LIKE VARIABLE    phys_strategy
{
}

trans1_TT_2_alert_key                             LIKE VARIABLE    phys_alert_key
{
}

trans1_TT_2_target_mode                           LIKE VARIABLE    phys_target_mode
{
}

trans1_TT_2_actual_mode                           LIKE VARIABLE    phys_actual_mode
{
}

trans1_TT_2_permitted_mode                        LIKE VARIABLE    phys_permitted_mode
{
}

trans1_TT_2_normal_mode                           LIKE VARIABLE    phys_normal_mode
{
}

trans1_TT_2_current_state_alarm_sum               LIKE VARIABLE    phys_current_state_alarm_sum
{
}

trans1_TT_2_unacknowledged_state_alarm_sum        LIKE VARIABLE    phys_unacknowledged_state_alarm_sum
{
}

trans1_TT_2_unreported_state_alarm_sum            LIKE VARIABLE    phys_unreported_state_alarm_sum
{
}

trans1_TT_2_disabled_state_alarm_sum              LIKE VARIABLE    phys_disabled_state_alarm_sum
{
}


/*---------------------------------------------------------------------*/
/*    Transducer Block: Temperature Transmitter                           */
/*---------------------------------------------------------------------*/

VARIABLE trans1_TT_2_lin_type             /* index 14 */
{
    LABEL       [trans_lin_type];
    HELP        [trans_lin_type_help];
    CLASS       DEVICE;
    HANDLING    READ & WRITE;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    102;
        { 0,      [linear]           },
        { 102,    [RTD_Pt100]        },
        { 105,    [RTD_Pt1000]       },
        { 240,    [MC_RTD_Cu50]      },
        { 127,    [RTD_Cu100]        },

        { 128,    [TC_type_B]        },
        { 131,    [TC_type_E]        },
        { 133,    [TC_type_J]        },
        { 134,    [TC_type_K]        },
        { 135,    [TC_type_N]        },
        { 136,    [TC_type_R]        },
        { 137,    [TC_type_S]        },
        { 138,    [TC_type_T]        },
    }
    POST_EDIT_ACTIONS
    {
        method_tt_2_lin_type
    }
}

VARIABLE trans1_TT_2_primary_value
{
    LABEL       [trans_value];
    HELP        [trans_temp_value_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    CONSTANT_UNIT SELECT (trans1_TT_2_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1243];CASE 1281: [unit_1281];}
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
    }
}

VARIABLE trans1_TT_2_primary_value_status_quality
{
    LABEL       [status_quality];
    HELP        [value_status_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        STATUS_OUTPUT_NO_RCAS
    }
}

trans1_TT_2_primary_value_status_limit            LIKE VARIABLE    trans1_TT_2_primary_value_status_quality
{
    REDEFINE LABEL       [status_limit];        
    REDEFINE TYPE        ENUMERATED (1)
    {
        STATUS_OUTPUT_LIMIT
    }
}

VARIABLE trans1_TT_2_primary_value_unit
{
    LABEL       [digital_units];
    HELP        [MC_digital_units_help];
    CLASS       DEVICE;
    HANDLING    READ & WRITE;
    TYPE        ENUMERATED (2)
    {
        IF (trans1_TT_2_lin_type==0 && trans1_TT_2_input_range==0)
        {
            { 1243, [unit_1243],    [unit_1243_help] }
        }
        ELSE
        {
            IF (trans1_TT_2_lin_type==0 && (trans1_TT_2_input_range==128 || trans1_TT_2_input_range==129))
            {
                { 1281, [unit_1281],    [unit_1281_help] }
            }
            ELSE
            {
                IF (trans1_TT_2_lin_type>0)
                {
                    { 1000, [unit_1000],    [unit_1000_help] },
                    { 1001, [unit_1001],    [unit_1001_help] },
                    { 1002, [unit_1002],    [unit_1002_help] },
                    { 1003, [unit_1003],    [unit_1003_help] }
                }
            }
        }
    }
    DEFAULT_VALUE IF (trans1_TT_2_lin_type == 0){1281;} ELSE {1001;}
    POST_EDIT_ACTIONS
    {
        method_TT_2_primary_value_unit
    }
    POST_WRITE_ACTIONS
    {
        method_TT_2_post_write_read_device_values
    }
}

VARIABLE trans1_TT_2_secondary_value_1
{
    LABEL       [trans_temp_secondary_value1];
    HELP        [trans_temp_secondary_value1_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    CONSTANT_UNIT SELECT (trans1_TT_2_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1243];CASE 1281: [unit_1281];}
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
    }
}

VARIABLE trans1_TT_2_secondary_value_1_status_quality
{
    LABEL       [status_quality];
    HELP        [value_status_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        STATUS_OUTPUT_NO_RCAS
    }
}

trans1_TT_2_secondary_value_1_status_limit            LIKE VARIABLE    trans1_TT_2_secondary_value_1_status_quality
{
    REDEFINE LABEL       [status_limit];        
    REDEFINE TYPE        ENUMERATED (1)
    {
        STATUS_OUTPUT_LIMIT
    }
}

VARIABLE trans1_TT_2_secondary_value_2
{
    LABEL       [trans_temp_secondary_value2];
    HELP        [trans_temp_secondary_value1_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    CONSTANT_UNIT SELECT (trans1_TT_2_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1243];CASE 1281: [unit_1281];}
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
    }
}

VARIABLE trans1_TT_2_secondary_value_2_status_quality
{
    LABEL       [status_quality];
    HELP        [value_status_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        STATUS_OUTPUT_NO_RCAS
    }
}

trans1_TT_2_secondary_value_2_status_limit            LIKE VARIABLE    trans1_TT_2_secondary_value_2_status_quality
{
    REDEFINE LABEL       [status_limit];        
    REDEFINE TYPE        ENUMERATED (1)
    {
        STATUS_OUTPUT_LIMIT
    }
}

VARIABLE trans1_TT_2_sensor_measure_type
{
    LABEL       [trans_temp_sensor_measure_type];
    HELP        [trans_temp_sensor_measure_type_help];
    CLASS       DEVICE;
    HANDLING    READ & WRITE;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE 1 ;
        /*{   0,      "PV=SV1"  },*/
        {   1,      "PV=SV2"  },
        IF (trans1_TT_1_primary_value_unit == trans1_TT_2_primary_value_unit)
        {
	        {   128,    "PV=SV1-SV2"    },
            {   129,    "PV=SV2-SV1"    },
            {   192,    "PV=0.5x(SV1+SV2)"}
        }
    }
}

VARIABLE trans1_TT_2_input_range
{
    LABEL       [trans_temp_input_range];
    HELP        [trans_temp_input_range_help];
    CLASS       DEVICE;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    128;
        {    0,      [MC_100MV]          },
        {    128,    [MC_500Ohm]         },
        {    129,    [MC_4000Ohm]        }
    }
    HANDLING    IF (trans1_TT_2_lin_type == 0)
                {   
                    READ & WRITE;
                }
                ELSE
                {
                    READ;
                }
    POST_EDIT_ACTIONS
    {
        method_tt_2_input_range
    }
}

VARIABLE trans1_TT_2_bias_1
{
    LABEL       [trans_temp_bias_1];
    HELP        [trans_temp_bias_1_help];
    CLASS       DEVICE;
    CONSTANT_UNIT SELECT (trans1_TT_2_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1243];CASE 1281: [unit_1281];}
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    0.0;
    }
    HANDLING    IF (trans1_TT_2_sensor_measure_type == 1)
                {
                    READ;
                }
                ELSE
                {
                    READ & WRITE;
                }
}

VARIABLE trans1_TT_2_bias_2
{
    LABEL       [trans_temp_bias_2];
    HELP        [trans_temp_bias_2_help];
    CLASS       DEVICE;
    CONSTANT_UNIT SELECT (trans1_TT_2_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1243];CASE 1281: [unit_1281];}
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    0.0;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_TT_2_upper_sensor_limit
{
    LABEL       [trans_sensor_upper_limit];
    HELP        [trans_sensor_upper_limit_help];
    CLASS       DEVICE;
    CONSTANT_UNIT SELECT (trans1_TT_2_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1243];CASE 1281: [unit_1281];}
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    850.00;
    }
    HANDLING    READ;
}

VARIABLE trans1_TT_2_lower_sensor_limit
{
    LABEL       [trans_sensor_lower_limit];
    HELP        [trans_sensor_lower_limit_help];
    CLASS       DEVICE;
    CONSTANT_UNIT SELECT (trans1_TT_2_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1243];CASE 1281: [unit_1281];}
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    -200.00;
    }
    HANDLING    READ;
}

VARIABLE trans1_TT_2_input_fault_gen
{
    LABEL       [trans_temp_input_fault];
    HELP        [trans_temp_input_fault_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    TYPE        BIT_ENUMERATED (1)
    {
        { 0x00,    [trans_temp_input_fault_OK]            },
        { 0x01,    [trans_temp_input_fault_RJ_ERR]        },
        { 0x02,    [trans_temp_input_fault_HW_ERR]        },
        { 0X40,    [MC_Comm_Err]                          }
    }
}

VARIABLE trans1_TT_2_input_fault_1
{
    LABEL       [trans_temp_input_fault_CH1_FAULT];
    HELP        [trans_temp_input_fault_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    TYPE        BIT_ENUMERATED (1)
    {
        { 0x00,    [trans_temp_input_fault_OK]                },
        /*{ 0x01,    [trans_temp_input_fault_UNDERRANGE]        },
        { 0x02,    [trans_temp_input_fault_OVERRANGE]        },*/
        { 0x04,    [trans_temp_input_fault_LEAD_BREAK]        },
        /*{ 0x08,    [trans_temp_input_fault_SHORT_CIRCUIT]    },*/
        { 0X40,    [MC_Comm_Err]                              }
    }
    STYLE       "MULTILINE 16 2" ;
}

VARIABLE trans1_TT_2_input_fault_2
{
    LABEL       [trans_temp_input_fault_CH2_FAULT];
    HELP        [trans_temp_input_fault_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    TYPE        BIT_ENUMERATED (1)
    {
        { 0x00,    [trans_temp_input_fault_OK]                },
        /*{ 0x01,    [trans_temp_input_fault_UNDERRANGE]        },
        { 0x02,    [trans_temp_input_fault_OVERRANGE]        },*/
        { 0x04,    [trans_temp_input_fault_LEAD_BREAK]        },
        /*{ 0x08,    [trans_temp_input_fault_SHORT_CIRCUIT]    },*/
        { 0X40,    [MC_Comm_Err]                              }
    }
    STYLE       "MULTILINE 16 2" ;
}

VARIABLE trans1_TT_2_sensor_wire_check_1
{
    LABEL       [trans_sensor_wire_check_1];
    HELP        [trans_sensor_wire_check_help];
    CLASS       DEVICE;
    HANDLING    READ & WRITE;
    TYPE        ENUMERATED (1)
    {
        { 0x00,    [trans_sensor_wire_check_BREAK_ON_SHORT_ON]     },
        { 0x01,    [trans_sensor_wire_check_BREAK_ON_SHORT_OFF]    },
        { 0x02,    [trans_sensor_wire_check_BREAK_OFF_SHORT_ON]    },
        { 0x03,    [MC_disabled]                                   }
    }
}

VARIABLE trans1_TT_2_sensor_wire_check_2
{
    LABEL       [trans_sensor_wire_check_2];
    HELP        [trans_sensor_wire_check_help];
    CLASS       DEVICE;
    HANDLING    READ & WRITE;
    TYPE        ENUMERATED (1)
    {
        { 0x00,    [trans_sensor_wire_check_BREAK_ON_SHORT_ON]     },
        { 0x01,    [trans_sensor_wire_check_BREAK_ON_SHORT_OFF]    },
        { 0x02,    [trans_sensor_wire_check_BREAK_OFF_SHORT_ON]    },
        { 0x03,    [MC_disabled]                                   }
    }
}

VARIABLE trans1_TT_2_external_rj_value
{
    LABEL       [trans_temp_external_rj_value];
    HELP        [trans_temp_external_rj_value_help];
    CLASS       DEVICE;
    HANDLING    READ & WRITE;
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
    }
}

VARIABLE trans1_TT_2_rj_temp
{
    LABEL       [trans_temp_rj_temp];
    HELP        [trans_temp_rj_temp_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    CONSTANT_UNIT SELECT (trans1_TT_2_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1001];CASE 1281: [unit_1001];}
    TYPE        FLOAT
    {
//        MIN_VALUE SELECT (trans1_TT_2_primary_value_unit) {CASE 1000: 233.15;CASE 1001: -40.0;CASE 1002: -40.0;CASE 1003: 419.67;}
//        MAX_VALUE SELECT (trans1_TT_2_primary_value_unit) {CASE 1000: 385.15;CASE 1001: 85.0;CASE 1002: 185.0;CASE 1003: 644.67;}
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE 0.0;
    }
}

VARIABLE trans1_TT_2_rj_type
{
    LABEL       [trans_temp_rj_type];
    HELP        [trans_temp_rj_type_help];
    CLASS       DEVICE;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    1;
        {    0,        [MC_trans_temp_rj_type_NONE]   },
        {    1,        [MC_trans_temp_rj_type_INT]    }
    }
    HANDLING    IF ((trans1_TT_2_lin_type == 102) || (trans1_TT_2_lin_type == 105) || 
                    (trans1_TT_2_lin_type == 240) || (trans1_TT_2_lin_type == 127) ||
                    (trans1_TT_2_lin_type == 0))
                {
                    READ;
                }
                ELSE
                {
                    READ & WRITE;
                }
}

/*---------------------------------------------------------------------*/
/*    Transducer Block: Thermoresistance Temperature Device (RTD)       */
/*---------------------------------------------------------------------*/

VARIABLE trans1_TT_2_sensor_connection
{
    LABEL       [trans_temp_sensor_connection];
    HELP        [trans_temp_sensor_connection_help];
    CLASS       DEVICE;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    1;
        {    0,    [trans_temp_sensor_connection_2_WIRE]        },
        {    1,    [trans_temp_sensor_connection_3_WIRE]        },
    /*    {    2,    [trans_temp_sensor_connection_4_WIRE]        }  */
    }
    HANDLING    IF ((trans1_TT_2_lin_type == 102) || (trans1_TT_2_lin_type == 105) || 
                    (trans1_TT_2_lin_type == 240) || (trans1_TT_2_lin_type == 127) ||
                    (trans1_TT_2_lin_type == 0))
                {   
                    READ & WRITE;
                }
                ELSE
                {
                    READ;
                }
}

/*---------------------------------------------------------------------*/
/*    Transducer Block: user defined                                   */
/*---------------------------------------------------------------------*/
VARIABLE trans1_TT_2_Cal_Point_Hi
{
    LABEL       [trans_cal_point_hi];
    HELP        [trans_cal_point_hi_help];
    CLASS       DEVICE;
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    850.00;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_TT_2_Cal_Point_Lo
{
    LABEL       [trans_cal_point_lo];
    HELP        [trans_cal_point_lo_help];
    CLASS       DEVICE;
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    -200.00;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_TT_2_Cal_Min_Span
{
    LABEL       [trans_cal_min_span];
    HELP        [trans_cal_min_span_help];
    CLASS       DEVICE;
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    0.0;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_TT_2_Cal_Unit
{
    LABEL       [trans_cal_unit];
    HELP        [trans_cal_unit_help];
    CLASS       DEVICE;
    TYPE        ENUMERATED (2)
    {
        DEFAULT_VALUE    1001;
        { 1001, [unit_1001],    [unit_1001_help] },
        { 1243, [unit_1243],    [unit_1243_help] },
        { 1281, [unit_1281],    [unit_1281_help] }
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_TT_2_Sensor_Value_1
{
    LABEL       [MC_Sensor_Value_1];
    HELP        [MC_Sensor_Value_1];
    CLASS       DEVICE & DYNAMIC;
    CONSTANT_UNIT SELECT (trans1_TT_2_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1243];CASE 1281: [unit_1281];}
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    0.0;
    }
    HANDLING    READ;
}

VARIABLE trans1_TT_2_Sensor_Value_2
{
    LABEL       [MC_Sensor_Value_2];
    HELP        [MC_Sensor_Value_2];
    CLASS       DEVICE & DYNAMIC;
    CONSTANT_UNIT SELECT (trans1_TT_2_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1243];CASE 1281: [unit_1281];}
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    0.0;
    }
    HANDLING    READ;
}

VARIABLE trans1_TT_2_Two_Wires_Comp
{
    LABEL       [MC_two_wires_compe];
    HELP        [MC_two_wires_compe];
    CLASS       DEVICE;
    HANDLING    READ & WRITE;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    1;
        {    0,    "finished"    },
        {    1,    "Start"       }
    }
}

/***********************************************************************/
/*    Unit relations                                                   */
/***********************************************************************/

/* Temperature Transducer Block */
UNIT TB_1_CAL_UNIT
{
    trans1_TT_1_Cal_Unit:

    trans1_TT_1_Cal_Point_Hi,
    trans1_TT_1_Cal_Point_Lo,
    trans1_TT_1_Cal_Min_Span
}

UNIT TB_2_CAL_UNIT
{
    trans1_TT_2_Cal_Unit:

    trans1_TT_2_Cal_Point_Hi,
    trans1_TT_2_Cal_Point_Lo,
    trans1_TT_2_Cal_Min_Span
}

/*---------------------------------------------------------------------*/
/*    Commands                                                         */
/*---------------------------------------------------------------------*/
COMMAND read_trans1_TT_1_blk
{
    BLOCK trans1_TT_1;
    INDEX 0;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_blk_reserve,
            trans1_TT_1_blk_object,
            trans1_TT_1_blk_parent_class,
            trans1_TT_1_blk_class,
            trans1_TT_1_blk_dd_reference,
            trans1_TT_1_blk_dd_rev,
            trans1_TT_1_blk_profile,
            trans1_TT_1_blk_profile_rev,
            trans1_TT_1_blk_execution_time,
            trans1_TT_1_blk_num_parameters,
            trans1_TT_1_blk_index_view_1,
            trans1_TT_1_blk_num_view_lists
        }
    }
}

COMMAND read_trans1_TT_1_st_rev
{
    BLOCK trans1_TT_1;
    INDEX 1;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_st_rev
        }
    }
}

COMMAND read_trans1_TT_1_tag_desc
{
    BLOCK trans1_TT_1;
    INDEX 2;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_tag_desc
        }
    }
}

COMMAND write_trans1_TT_1_tag_desc
{
    BLOCK trans1_TT_1;
    INDEX 2;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_tag_desc
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_strategy
{
    BLOCK trans1_TT_1;
    INDEX 3;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_strategy
        }
    }
}

COMMAND write_trans1_TT_1_strategy
{
    BLOCK trans1_TT_1;
    INDEX 3;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_strategy
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_alert_key
{
    BLOCK trans1_TT_1;
    INDEX 4;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_alert_key
        }
    }
}

COMMAND write_trans1_TT_1_alert_key
{
    BLOCK trans1_TT_1;
    INDEX 4;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_alert_key
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_target_mode
{
    BLOCK trans1_TT_1;
    INDEX 5;
    OPERATION  READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_target_mode
        }
    }
}

COMMAND write_trans1_TT_1_target_mode
{
    BLOCK trans1_TT_1;
    INDEX 5;
    OPERATION  WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_target_mode
        }
        REPLY
        {
        }
    }
}


COMMAND read_trans1_TT_1_mode
{
    BLOCK trans1_TT_1;
    INDEX 6;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_actual_mode,
            trans1_TT_1_permitted_mode,
            trans1_TT_1_normal_mode
        }
    }
}

COMMAND read_trans1_TT_1_alarm
{
    BLOCK trans1_TT_1;
    INDEX 7;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_current_state_alarm_sum,
            trans1_TT_1_unacknowledged_state_alarm_sum,
            trans1_TT_1_unreported_state_alarm_sum,
            trans1_TT_1_disabled_state_alarm_sum
        }
    }
}

COMMAND read_trans1_TT_1_primary_value
{
    BLOCK trans1_TT_1;
    INDEX 8;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_primary_value,
            trans1_TT_1_primary_value_status_quality    <0xFC>,
            trans1_TT_1_primary_value_status_limit    <0x03>
        }
    }
}

COMMAND read_trans1_TT_1_primary_value_unit
{
    BLOCK trans1_TT_1;
    INDEX 9;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_primary_value_unit
        }
    }
}

COMMAND write_trans1_TT_1_primary_value_unit
{
    BLOCK trans1_TT_1;
    INDEX 9;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_primary_value_unit
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_secondary_value_1
{
    BLOCK trans1_TT_1;
    INDEX 10;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_secondary_value_1,
            trans1_TT_1_secondary_value_1_status_quality    <0xFC>,
            trans1_TT_1_secondary_value_1_status_limit    <0x03>
        }
    }
}

COMMAND read_trans1_TT_1_secondary_value_2
{
    BLOCK trans1_TT_1;
    INDEX 11;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_secondary_value_2,
            trans1_TT_1_secondary_value_2_status_quality    <0xFC>,
            trans1_TT_1_secondary_value_2_status_limit    <0x03>
        }
    }
}

COMMAND read_trans1_TT_1_sensor_measure_type
{
    BLOCK trans1_TT_1;
    INDEX 12;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_sensor_measure_type
        }
    }
}

COMMAND write_trans1_TT_1_sensor_measure_type
{
    BLOCK trans1_TT_1;
    INDEX 12;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_sensor_measure_type
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_input_range
{
    BLOCK trans1_TT_1;
    INDEX 13;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_input_range
        }
    }
}

COMMAND write_trans1_TT_1_input_range
{
    BLOCK trans1_TT_1;
    INDEX 13;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_input_range
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_lin_type
{
    BLOCK trans1_TT_1;
    INDEX 14;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_lin_type
        }
    }
}

COMMAND write_trans1_TT_1_lin_type
{
    BLOCK trans1_TT_1;
    INDEX 14;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_lin_type
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_bias_1
{
    BLOCK trans1_TT_1;
    INDEX 19;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_bias_1
        }
    }
}

COMMAND write_trans1_TT_1_bias_1
{
    BLOCK trans1_TT_1;
    INDEX 19;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_bias_1
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_bias_2
{
    BLOCK trans1_TT_1;
    INDEX 20;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_bias_2
        }
    }
}

COMMAND write_trans1_TT_1_bias_2
{
    BLOCK trans1_TT_1;
    INDEX 20;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_bias_2
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_upper_sensor_limit
{
    BLOCK trans1_TT_1;
    INDEX 21;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_upper_sensor_limit
        }
    }
}

COMMAND read_trans1_TT_1_lower_sensor_limit
{
    BLOCK trans1_TT_1;
    INDEX 22;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_lower_sensor_limit
        }
    }
}

COMMAND read_trans1_TT_1_input_fault_gen
{
    BLOCK trans1_TT_1;
    INDEX 24;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_input_fault_gen
        }
    }
}

COMMAND read_trans1_TT_1_input_fault_1
{
    BLOCK trans1_TT_1;
    INDEX 25;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_input_fault_1
        }
    }
}

COMMAND read_trans1_TT_1_input_fault_2
{
    BLOCK trans1_TT_1;
    INDEX 26;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_input_fault_2
        }
    }
}

COMMAND read_trans1_TT_1_rj_temp
{
    BLOCK trans1_TT_1;
    INDEX 33;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_rj_temp
        }
    }
}

COMMAND read_trans1_TT_1_rj_type
{
    BLOCK trans1_TT_1;
    INDEX 34;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_rj_type
        }
    }
}

COMMAND write_trans1_TT_1_rj_type
{
    BLOCK trans1_TT_1;
    INDEX 34;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_rj_type
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_external_rj_value
{
    BLOCK trans1_TT_1;
    INDEX 35;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_external_rj_value
        }
    }
}

COMMAND write_trans1_TT_1_external_rj_value
{
    BLOCK trans1_TT_1;
    INDEX 35;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_external_rj_value
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_sensor_connection
{
    BLOCK trans1_TT_1;
    INDEX 36;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_sensor_connection
        }
    }
}

COMMAND write_trans1_TT_1_sensor_connection
{
    BLOCK trans1_TT_1;
    INDEX 36;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_sensor_connection
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_Cal_Point_Hi
{
    BLOCK trans1_TT_1;
    INDEX 62;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_Cal_Point_Hi
        }
    }
}

COMMAND write_trans1_TT_1_Cal_Point_Hi
{
    BLOCK trans1_TT_1;
    INDEX 62;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_Cal_Point_Hi
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_Cal_Point_Lo
{
    BLOCK trans1_TT_1;
    INDEX 63;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_Cal_Point_Lo
        }
    }
}

COMMAND write_trans1_TT_1_Cal_Point_Lo
{
    BLOCK trans1_TT_1;
    INDEX 63;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_Cal_Point_Lo
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_Cal_Min_Span
{
    BLOCK trans1_TT_1;
    INDEX 64;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_Cal_Min_Span
        }
    }
}

COMMAND write_trans1_TT_1_Cal_Min_Span
{
    BLOCK trans1_TT_1;
    INDEX 64;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_Cal_Min_Span
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_Cal_Unit
{
    BLOCK trans1_TT_1;
    INDEX 65;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_Cal_Unit
        }
    }
}

COMMAND write_trans1_TT_1_Cal_Unit
{
    BLOCK trans1_TT_1;
    INDEX 65;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_Cal_Unit
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_Sensor_Value_1
{
    BLOCK trans1_TT_1;
    INDEX 67;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_Sensor_Value_1
        }
    }
}

COMMAND read_trans1_TT_1_Sensor_Value_2
{
    BLOCK trans1_TT_1;
    INDEX 68;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_Sensor_Value_2
        }
    }
}

COMMAND read_trans1_TT_1_Two_Wires_Comp
{
    BLOCK trans1_TT_1;
    INDEX 69;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_Two_Wires_Comp
        }
    }
}

COMMAND write_trans1_TT_1_Two_Wires_Comp
{
    BLOCK trans1_TT_1;
    INDEX 69;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_Two_Wires_Comp
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_2_blk
{
    BLOCK trans1_TT_2;
    INDEX 0;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_blk_reserve,
            trans1_TT_2_blk_object,
            trans1_TT_2_blk_parent_class,
            trans1_TT_2_blk_class,
            trans1_TT_2_blk_dd_reference,
            trans1_TT_2_blk_dd_rev,
            trans1_TT_2_blk_profile,
            trans1_TT_2_blk_profile_rev,
            trans1_TT_2_blk_execution_time,
            trans1_TT_2_blk_num_parameters,
            trans1_TT_2_blk_index_view_1,
            trans1_TT_2_blk_num_view_lists
        }
    }
}

COMMAND read_trans1_TT_2_st_rev
{
    BLOCK trans1_TT_2;
    INDEX 1;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_st_rev
        }
    }
}

COMMAND read_trans1_TT_2_tag_desc
{
    BLOCK trans1_TT_2;
    INDEX 2;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_tag_desc
        }
    }
}

COMMAND write_trans1_TT_2_tag_desc
{
    BLOCK trans1_TT_2;
    INDEX 2;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_2_tag_desc
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_2_strategy
{
    BLOCK trans1_TT_2;
    INDEX 3;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_strategy
        }
    }
}

COMMAND write_trans1_TT_2_strategy
{
    BLOCK trans1_TT_2;
    INDEX 3;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_2_strategy
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_2_alert_key
{
    BLOCK trans1_TT_2;
    INDEX 4;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_alert_key
        }
    }
}

COMMAND write_trans1_TT_2_alert_key
{
    BLOCK trans1_TT_2;
    INDEX 4;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_2_alert_key
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_2_target_mode
{
    BLOCK trans1_TT_2;
    INDEX 5;
    OPERATION  READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_target_mode
        }
    }
}

COMMAND write_trans1_TT_2_target_mode
{
    BLOCK trans1_TT_2;
    INDEX 5;
    OPERATION  WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_2_target_mode
        }
        REPLY
        {
        }
    }
}


COMMAND read_trans1_TT_2_mode
{
    BLOCK trans1_TT_2;
    INDEX 6;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_actual_mode,
            trans1_TT_2_permitted_mode,
            trans1_TT_2_normal_mode
        }
    }
}

COMMAND read_trans1_TT_2_alarm
{
    BLOCK trans1_TT_2;
    INDEX 7;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_current_state_alarm_sum,
            trans1_TT_2_unacknowledged_state_alarm_sum,
            trans1_TT_2_unreported_state_alarm_sum,
            trans1_TT_2_disabled_state_alarm_sum
        }
    }
}

COMMAND read_trans1_TT_2_primary_value
{
    BLOCK trans1_TT_2;
    INDEX 8;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_primary_value,
            trans1_TT_2_primary_value_status_quality    <0xFC>,
            trans1_TT_2_primary_value_status_limit    <0x03>
        }
    }
}

COMMAND read_trans1_TT_2_primary_value_unit
{
    BLOCK trans1_TT_2;
    INDEX 9;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_primary_value_unit
        }
    }
}

COMMAND write_trans1_TT_2_primary_value_unit
{
    BLOCK trans1_TT_2;
    INDEX 9;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_2_primary_value_unit
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_2_secondary_value_1
{
    BLOCK trans1_TT_2;
    INDEX 10;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_secondary_value_1,
            trans1_TT_2_secondary_value_1_status_quality    <0xFC>,
            trans1_TT_2_secondary_value_1_status_limit    <0x03>
        }
    }
}

COMMAND read_trans1_TT_2_secondary_value_2
{
    BLOCK trans1_TT_2;
    INDEX 11;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_secondary_value_2,
            trans1_TT_2_secondary_value_2_status_quality    <0xFC>,
            trans1_TT_2_secondary_value_2_status_limit    <0x03>
        }
    }
}

COMMAND read_trans1_TT_2_sensor_measure_type
{
    BLOCK trans1_TT_2;
    INDEX 12;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_sensor_measure_type
        }
    }
}

COMMAND write_trans1_TT_2_sensor_measure_type
{
    BLOCK trans1_TT_2;
    INDEX 12;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_2_sensor_measure_type
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_2_input_range
{
    BLOCK trans1_TT_2;
    INDEX 13;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_input_range
        }
    }
}

COMMAND write_trans1_TT_2_input_range
{
    BLOCK trans1_TT_2;
    INDEX 13;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_2_input_range
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_2_lin_type
{
    BLOCK trans1_TT_2;
    INDEX 14;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_lin_type
        }
    }
}

COMMAND write_trans1_TT_2_lin_type
{
    BLOCK trans1_TT_2;
    INDEX 14;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_2_lin_type
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_2_bias_1
{
    BLOCK trans1_TT_2;
    INDEX 19;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_bias_1
        }
    }
}

COMMAND write_trans1_TT_2_bias_1
{
    BLOCK trans1_TT_2;
    INDEX 19;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_2_bias_1
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_2_bias_2
{
    BLOCK trans1_TT_2;
    INDEX 20;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_bias_2
        }
    }
}

COMMAND write_trans1_TT_2_bias_2
{
    BLOCK trans1_TT_2;
    INDEX 20;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_2_bias_2
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_2_upper_sensor_limit
{
    BLOCK trans1_TT_2;
    INDEX 21;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_upper_sensor_limit
        }
    }
}

COMMAND read_trans1_TT_2_lower_sensor_limit
{
    BLOCK trans1_TT_2;
    INDEX 22;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_lower_sensor_limit
        }
    }
}

COMMAND read_trans1_TT_2_input_fault_gen
{
    BLOCK trans1_TT_2;
    INDEX 24;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_input_fault_gen
        }
    }
}

COMMAND read_trans1_TT_2_input_fault_1
{
    BLOCK trans1_TT_2;
    INDEX 25;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_input_fault_1
        }
    }
}

COMMAND read_trans1_TT_2_input_fault_2
{
    BLOCK trans1_TT_2;
    INDEX 26;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_input_fault_2
        }
    }
}

COMMAND read_trans1_TT_2_rj_temp
{
    BLOCK trans1_TT_2;
    INDEX 33;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_rj_temp
        }
    }
}

COMMAND read_trans1_TT_2_rj_type
{
    BLOCK trans1_TT_2;
    INDEX 34;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_rj_type
        }
    }
}

COMMAND write_trans1_TT_2_rj_type
{
    BLOCK trans1_TT_2;
    INDEX 34;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_2_rj_type
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_2_external_rj_value
{
    BLOCK trans1_TT_2;
    INDEX 35;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_external_rj_value
        }
    }
}

COMMAND write_trans1_TT_2_external_rj_value
{
    BLOCK trans1_TT_2;
    INDEX 35;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_2_external_rj_value
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_2_sensor_connection
{
    BLOCK trans1_TT_2;
    INDEX 36;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_sensor_connection
        }
    }
}

COMMAND write_trans1_TT_2_sensor_connection
{
    BLOCK trans1_TT_2;
    INDEX 36;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_2_sensor_connection
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_2_Cal_Point_Hi
{
    BLOCK trans1_TT_2;
    INDEX 62;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_Cal_Point_Hi
        }
    }
}

COMMAND write_trans1_TT_2_Cal_Point_Hi
{
    BLOCK trans1_TT_2;
    INDEX 62;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_2_Cal_Point_Hi
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_2_Cal_Point_Lo
{
    BLOCK trans1_TT_2;
    INDEX 63;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_Cal_Point_Lo
        }
    }
}

COMMAND write_trans1_TT_2_Cal_Point_Lo
{
    BLOCK trans1_TT_2;
    INDEX 63;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_2_Cal_Point_Lo
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_2_Cal_Min_Span
{
    BLOCK trans1_TT_2;
    INDEX 64;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_Cal_Min_Span
        }
    }
}

COMMAND write_trans1_TT_2_Cal_Min_Span
{
    BLOCK trans1_TT_2;
    INDEX 64;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_2_Cal_Min_Span
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_2_Cal_Unit
{
    BLOCK trans1_TT_2;
    INDEX 65;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_Cal_Unit
        }
    }
}

COMMAND write_trans1_TT_2_Cal_Unit
{
    BLOCK trans1_TT_2;
    INDEX 65;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_2_Cal_Unit
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_2_Sensor_Value_1
{
    BLOCK trans1_TT_2;
    INDEX 67;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_Sensor_Value_1
        }
    }
}

COMMAND read_trans1_TT_2_Sensor_Value_2
{
    BLOCK trans1_TT_2;
    INDEX 68;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_Sensor_Value_2
        }
    }
}

COMMAND read_trans1_TT_2_Two_Wires_Comp
{
    BLOCK trans1_TT_2;
    INDEX 69;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_2_Two_Wires_Comp
        }
    }
}

COMMAND write_trans1_TT_2_Two_Wires_Comp
{
    BLOCK trans1_TT_2;
    INDEX 69;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_2_Two_Wires_Comp
        }
        REPLY
        {
        }
    }
}

/***********************************************************************/
/*****    Menu: Specialist  **********************************************/
/***********************************************************************/

MENU Menu_Main_Specialist
{
    LABEL        [main_menu];
    ITEMS
    {
        Menu_File,
        Menu_S_Device,
        Menu_S_View,
        Menu_Options,
        Menu_Help
    }
}

/***********************************************************************/
/*****    Menu: Maintenance  *********************************************/
/***********************************************************************/

MENU Menu_Main_Maintenance
{
    LABEL        [main_menu];
    ITEMS
    {
        Menu_File,
        Menu_M_Device,
        Menu_M_View,
        Menu_Options,
        Menu_Help
    }
}

//MENU download_variables
//{
//    LABEL        [menu_load_to_PC];
//    ITEMS
//    {
//    /* PHYSICAL BLOCK    */
//        phys_st_rev,
//        phys_device_man_id,
//        phys_device_id,
//        phys_tag_desc,
//        phys_descriptor,
//        phys_message,
//        phys_install_date,
//        phys_software_rev,
//        phys_hardware_rev,
//        phys_blk_profile,
//        phys_blk_profile_rev,
//        phys_blk_dd_reference,
//        phys_blk_dd_rev,
//        phys_device_certification,
//        phys_device_ser_num,
//
//    /* FUNCTION BLOCK 1: AI 1    */
//        func1_AI_1_tag_desc,
//        func1_AI_1_strategy,
//        func1_AI_1_alert_key,
//        func1_AI_1_target_mode,
//        func1_AI_1_batch_id,
//        func1_AI_1_batch_unit,
//        func1_AI_1_batch_operation,
//        func1_AI_1_batch_phase,
//        func1_AI_1_channel,
//        func1_AI_1_lin_type,
//        func1_AI_1_pv_ftime,
//        func1_AI_1_pv_upper_range_value,
//        func1_AI_1_pv_lower_range_value,
//        func1_AI_1_out_upper_range_value,
//        func1_AI_1_out_lower_range_value,
//        func1_AI_1_out_unit,
//        func1_AI_1_out_decimal_point,
//        func1_AI_1_alarm_hys,
//        func1_AI_1_hi_hi_lim,
//        func1_AI_1_hi_lim,
//        func1_AI_1_lo_lim,
//        func1_AI_1_lo_lo_lim,
//        func1_AI_1_FSafeType,
//        func1_AI_1_FSafeValue,
//        func1_AI_1_out_unit_text,
//
//    /* FUNCTION BLOCK 1: AI 2    */
//        func1_AI_2_tag_desc,
//        func1_AI_2_strategy,
//        func1_AI_2_alert_key,
//        func1_AI_2_target_mode,
//        func1_AI_2_batch_id,
//        func1_AI_2_batch_unit,
//        func1_AI_2_batch_operation,
//        func1_AI_2_batch_phase,
//        func1_AI_2_channel,
//        func1_AI_2_lin_type,
//        func1_AI_2_pv_ftime,
//        func1_AI_2_pv_upper_range_value,
//        func1_AI_2_pv_lower_range_value,
//        func1_AI_2_out_upper_range_value,
//        func1_AI_2_out_lower_range_value,
//        func1_AI_2_out_unit,
//        func1_AI_2_out_decimal_point,
//        func1_AI_2_alarm_hys,
//        func1_AI_2_hi_hi_lim,
//        func1_AI_2_hi_lim,
//        func1_AI_2_lo_lim,
//        func1_AI_2_lo_lo_lim,
//        func1_AI_2_FSafeType,
//        func1_AI_2_FSafeValue,
//        func1_AI_2_out_unit_text
//
//    /* TRANDSDUCER BLOCK 1: */
//        trans1_TT_1_st_rev,
//        trans1_TT_1_tag_desc,
//        trans1_TT_1_st_rev,
//        trans1_TT_1_lin_type,
//        trans1_TT_1_primary_value_unit,
//        trans1_TT_1_sensor_measure_type,
//        trans1_TT_1_input_range,
//        trans1_TT_1_rj_type,
//        trans1_TT_1_bias_1,
//        trans1_TT_1_bias_2,
//        trans1_TT_1_sensor_connection,
//        trans1_TT_1_lower_sensor_limit,
//        trans1_TT_1_upper_sensor_limit,
//    
//    /* TRANDSDUCER BLOCK 2: */
//        trans1_TT_2_st_rev,
//        trans1_TT_2_tag_desc,
//        trans1_TT_2_st_rev,
//        trans1_TT_2_lin_type,
//        trans1_TT_2_primary_value_unit,
//        trans1_TT_2_sensor_measure_type,
//        trans1_TT_2_input_range,
//        trans1_TT_2_rj_type,
//        trans1_TT_2_bias_1,
//        trans1_TT_2_bias_2,
//        trans1_TT_2_sensor_connection,
//        trans1_TT_2_lower_sensor_limit,
//        trans1_TT_2_upper_sensor_limit
//    }
//}

MENU upload_variables
{
    LABEL        [menu_load_to_device];
    ITEMS
    {
    /* PHYSICAL BLOCK    */
        phys_tag_desc,
        phys_descriptor,
        phys_message,
        phys_install_date,
        phys_local_operation_enable,
        phys_strategy,
        phys_alert_key,
        phys_lcd_dsp_channel,
        phys_lcd_dsp_type_index,
        phys_lcd_dsp_decimal_point,

    /* FUNCTION BLOCK 1: AI 1    */
        func1_AI_1_tag_desc,
        func1_AI_1_strategy,
        func1_AI_1_alert_key,
        func1_AI_1_target_mode,
        func1_AI_1_batch_id,
        func1_AI_1_batch_unit,
        func1_AI_1_batch_operation,
        func1_AI_1_batch_phase,
        func1_AI_1_channel,
        func1_AI_1_lin_type,
        func1_AI_1_pv_ftime,
        func1_AI_1_pv_upper_range_value,
        func1_AI_1_pv_lower_range_value,
        func1_AI_1_out_upper_range_value,
        func1_AI_1_out_lower_range_value,
        func1_AI_1_out_unit,
        func1_AI_1_out_decimal_point,
        func1_AI_1_alarm_hys,
        func1_AI_1_hi_hi_lim,
        func1_AI_1_hi_lim,
        func1_AI_1_lo_lim,
        func1_AI_1_lo_lo_lim,
        func1_AI_1_FSafeType,
        func1_AI_1_FSafeValue,
        func1_AI_1_out_unit_text,

    /* FUNCTION BLOCK 1: AI 2    */
        func1_AI_2_tag_desc,
        func1_AI_2_strategy,
        func1_AI_2_alert_key,
        func1_AI_2_target_mode,
        func1_AI_2_batch_id,
        func1_AI_2_batch_unit,
        func1_AI_2_batch_operation,
        func1_AI_2_batch_phase,
        func1_AI_2_channel,
        func1_AI_2_lin_type,
        func1_AI_2_pv_ftime,
        func1_AI_2_pv_upper_range_value,
        func1_AI_2_pv_lower_range_value,
        func1_AI_2_out_upper_range_value,
        func1_AI_2_out_lower_range_value,
        func1_AI_2_out_unit,
        func1_AI_2_out_decimal_point,
        func1_AI_2_alarm_hys,
        func1_AI_2_hi_hi_lim,
        func1_AI_2_hi_lim,
        func1_AI_2_lo_lim,
        func1_AI_2_lo_lo_lim,
        func1_AI_2_FSafeType,
        func1_AI_2_FSafeValue,
        func1_AI_2_out_unit_text,

    /* TRANDSDUCER BLOCK 1: */
        trans1_TT_1_st_rev,
        trans1_TT_1_tag_desc,
        trans1_TT_1_st_rev,
        trans1_TT_1_lin_type,
        trans1_TT_1_primary_value_unit,
        trans1_TT_1_sensor_measure_type,
        IF (trans1_TT_1_lin_type == 0)
        {    trans1_TT_1_input_range,}
        IF ((trans1_TT_1_lin_type == 128) || (trans1_TT_1_lin_type == 131) || 
            ((trans1_TT_1_lin_type >= 133) && (trans1_TT_1_lin_type <= 138)))
        {   trans1_TT_1_rj_type,}
        trans1_TT_1_bias_1,
        IF (trans1_TT_1_sensor_measure_type != 0)
        {   trans1_TT_1_bias_2,}
        trans1_TT_1_sensor_connection,
        trans1_TT_1_lower_sensor_limit,
        trans1_TT_1_upper_sensor_limit,
    
    /* TRANDSDUCER BLOCK 2: */
        trans1_TT_2_st_rev,
        trans1_TT_2_tag_desc,
        trans1_TT_2_st_rev,
        trans1_TT_2_lin_type,
        trans1_TT_2_primary_value_unit,
        trans1_TT_2_sensor_measure_type,
        IF (trans1_TT_2_lin_type == 0)
        {    trans1_TT_2_input_range,}
        IF ((trans1_TT_2_lin_type == 128) || (trans1_TT_2_lin_type == 131) || 
            ((trans1_TT_2_lin_type >= 133) && (trans1_TT_2_lin_type <= 138)))
        {   trans1_TT_2_rj_type,}
        IF (trans1_TT_2_sensor_measure_type != 1)
        {   trans1_TT_2_bias_1,}
        trans1_TT_2_bias_2,
        trans1_TT_2_sensor_connection,
        trans1_TT_2_lower_sensor_limit,
        trans1_TT_2_upper_sensor_limit,
    }
    PRE_READ_ACTIONS
    {
        method_pre_write_phys_write_locking
    }
}




/*---------------------------------------------------------------------*/
/*    Menu: Device                                                     */
/*---------------------------------------------------------------------*/

MENU Menu_S_Device
{
    LABEL        [menu_Device];
    ITEMS
    {
        std_NodeAddress,
        SEPARATOR,
        std_LoadinDevice,
        std_LoadinPC,
        SEPARATOR,
        Menu_configuration,
        SEPARATOR,
        Menu_cal,
        OnlineWindow_simulation,
        SEPARATOR,
        OnlineDialog_reset,
        OnlineDialog_write_locking,
        OnlineDialog_ident_number
    }
}

MENU Menu_M_Device
{
    LABEL        [menu_Device];
    ITEMS
    {
        std_NodeAddress,
        SEPARATOR,
        std_LoadinDevice,
        std_LoadinPC
    }
}

MENU Menu_configuration
{
    LABEL "Configuration";
    ITEMS
    {
        OnlineWindow_trans1_TT_1_setting,
        OnlineWindow_trans1_TT_2_setting,
        OnlineWindow_AI_1_geral,
        OnlineWindow_AI_2_geral,
        OnlineWindow_LCD_display
    }
}

//MENU Menu_online
//{
//    LABEL [MC_Online_Conf];
//    ITEMS
//    {
//        Menu_func1_AI_1_online,
//        Menu_func1_AI_2_online
//    }
//}
//
//MENU Menu_offline
//{
//    LABEL [MC_Offline_Conf];
//    ITEMS
//    {
//        OfflineWindow_trans1_TT_1_setting,
//        OfflineWindow_trans1_TT_2_setting,
//        OfflineWindow_AI_1_geral,
//        OfflineWindow_AI_2_geral,
//        OfflineWindow_LCD_display
//    }
//}

MENU OnlineWindow_trans1_TT_1_setting
{
    LABEL [trans1];
    ITEMS
    {
        Page_trans1_TT_1_Basic_Settings,
        Page_trans1_TT_1_Advanced_Settings
    }
}

MENU Page_trans1_TT_1_Basic_Settings
{
    LABEL [MC_Tab_basic];
    ITEMS
    {
        Group_trans1_TT_1_Measure_Type,
        Group_trans1_TT_1_Sensor_Type,
        Group_trans1_TT_1_Connection_Type,
        Group_trans1_TT_1_RJ_Type,
        SEPARATOR
    }
}

MENU Group_trans1_TT_1_Measure_Type
{
    LABEL [MC_Select_Measure_Type];
    ITEMS
    {
        trans1_TT_1_sensor_measure_type
//        SEPARATOR,
//        method_write_trans1_TT_1_sensor_measure_type
    }
}

MENU Group_trans1_TT_1_Sensor_Type
{
    LABEL [MC_Select_Sensor_Type];
    ITEMS
    {
        trans1_TT_1_lin_type,
        trans1_TT_1_input_range
//        SEPARATOR,
//        method_write_trans1_TT_1_Sensor_type
    }
}

MENU Group_trans1_TT_1_Connection_Type
{
    LABEL [MC_Select_Connection_Type];
    ITEMS
    {
        trans1_TT_1_sensor_connection
//        SEPARATOR,
//        method_write_trans1_TT_1_sensor_connection
    }
}

MENU Group_trans1_TT_1_RJ_Type
{
    LABEL [MC_Select_RJ_Type];
    ITEMS
    {
        trans1_TT_1_rj_type
//        SEPARATOR,
//        method_write_trans1_TT_1_rj_type
    }
}

MENU OnlineWindow_trans1_TT_2_setting
{
    LABEL [trans2];
    ITEMS
    {
        Page_trans1_TT_2_Basic_Settings,
        Page_trans1_TT_2_Advanced_Settings
    }
}

MENU Page_trans1_TT_2_Basic_Settings
{
    LABEL [MC_Tab_basic];
    ITEMS
    {
        Group_trans1_TT_2_Measure_Type,
        Group_trans1_TT_2_Sensor_Type,
        Group_trans1_TT_2_Connection_Type,
        Group_trans1_TT_2_RJ_Type,
        SEPARATOR
    }
}

MENU Group_trans1_TT_2_Measure_Type
{
    LABEL [MC_Select_Measure_Type];
    ITEMS
    {
        trans1_TT_2_sensor_measure_type
//        SEPARATOR,
//        method_write_trans1_TT_2_sensor_measure_type
    }
}

MENU Group_trans1_TT_2_Sensor_Type
{
    LABEL [MC_Select_Sensor_Type];
    ITEMS
    {
        trans1_TT_2_lin_type,
        trans1_TT_2_input_range
//        SEPARATOR,
//        method_write_trans1_TT_2_Sensor_type
    }
}

MENU Group_trans1_TT_2_Connection_Type
{
    LABEL [MC_Select_Connection_Type];
    ITEMS
    {
        trans1_TT_2_sensor_connection
//        SEPARATOR,
//        method_write_trans1_TT_2_sensor_connection
    }
}

MENU Group_trans1_TT_2_RJ_Type
{
    LABEL [MC_Select_RJ_Type];
    ITEMS
    {
        trans1_TT_2_rj_type
//        SEPARATOR,
//        method_write_trans1_TT_2_rj_type
    }
}





MENU Page_trans1_TT_1_Advanced_Settings
{
    LABEL [MC_Tab_advanced];
    ITEMS
    {
        Group_trans1_TT_1_primary_value_unit,
        Group_trans1_TT_1_bias_of_channel,
        Group_trans1_TT_1_2wire_compensation,
        Group_trans1_TT_1_sensor_limit,
        SEPARATOR
    }
}

MENU Group_trans1_TT_1_primary_value_unit
{
    LABEL [MC_Select_Output_Unit];
    ITEMS
    {
        trans1_TT_1_primary_value_unit
//        SEPARATOR,
//        method_write_trans1_TT_1_primary_value_unit
    }
}

MENU Group_trans1_TT_1_bias_of_channel
{
    LABEL [MC_Set_Bias_of_Channel];
    ITEMS
    {
        trans1_TT_1_bias_1,
        trans1_TT_1_bias_2
//        SEPARATOR,
//        method_write_trans1_TT_1_bias_1,
//        method_write_trans1_TT_1_bias_2
    }
}

MENU Group_trans1_TT_1_2wire_compensation
{
    LABEL [MC_Set_2Wire_Comp];
    ITEMS
    {
        method_set_trans1_TT_1_two_Wires_Comp
    }
}

MENU Group_trans1_TT_1_sensor_limit
{
    LABEL [MC_Sensor_Limits];
    ITEMS
    {
        trans1_TT_1_lower_sensor_limit,
        trans1_TT_1_upper_sensor_limit
    }
}

MENU Page_trans1_TT_2_Advanced_Settings
{
    LABEL [MC_Tab_advanced];
    ITEMS
    {
        Group_trans1_TT_2_primary_value_unit,
        Group_trans1_TT_2_bias_of_channel,
        Group_trans1_TT_2_2wire_compensation,
        Group_trans1_TT_2_sensor_limit,
        SEPARATOR
    }
}

MENU Group_trans1_TT_2_primary_value_unit
{
    LABEL [MC_Select_Output_Unit];
    ITEMS
    {
        trans1_TT_2_primary_value_unit
//        SEPARATOR,
//        method_write_trans1_TT_2_primary_value_unit
    }
}

MENU Group_trans1_TT_2_bias_of_channel
{
    LABEL [MC_Set_Bias_of_Channel];
    ITEMS
    {
        trans1_TT_2_bias_1,
        trans1_TT_2_bias_2
//        SEPARATOR,
//        method_write_trans1_TT_2_bias_1,
//        method_write_trans1_TT_2_bias_2
    }
}

MENU Group_trans1_TT_2_2wire_compensation
{
    LABEL [MC_Set_2Wire_Comp];
    ITEMS
    {
        method_set_trans1_TT_2_two_Wires_Comp
    }
}

MENU Group_trans1_TT_2_sensor_limit
{
    LABEL [MC_Sensor_Limits];
    ITEMS
    {
        trans1_TT_2_lower_sensor_limit,
        trans1_TT_2_upper_sensor_limit
    }
}

MENU Menu_cal
{
    LABEL        [MC_menu_cal];
    ITEMS
    {
        OnlineDialog_trans1_TT_1_cal,
        OnlineDialog_trans1_TT_2_cal
    }
}

MENU OnlineDialog_trans1_TT_1_cal
{
    LABEL        [MC_cal_trd1];
    ITEMS
    {
        Page_trans1_TT_1_cal_para,
        Page_trans1_TT_1_cal_lo_point,
        Page_trans1_TT_1_cal_hi_point
    }
}

MENU Page_trans1_TT_1_cal_para
{
    LABEL     [MC_cal_para];
    ITEMS
    {
        trans1_TT_1_Cal_Unit,
        trans1_TT_1_lin_type,
        trans1_TT_1_input_range,
        SEPARATOR,
        method_set
    }
}

MENU Page_trans1_TT_1_cal_lo_point
{
    LABEL     [MC_cal_lo_point];
    ITEMS
    {
        trans1_TT_1_lower_sensor_limit (READ_ONLY),
        trans1_TT_1_Cal_Point_Lo (READ_ONLY),
        trans1_TT_1_Sensor_Value_1,
        //trans1_TT_1_Sensor_Value_2,
        SEPARATOR,
        method_set_trans1_TT_1_cal_point_lo
    }
}

MENU Page_trans1_TT_1_cal_hi_point
{
    LABEL     [MC_cal_hi_point];
    ITEMS
    {
        trans1_TT_1_upper_sensor_limit (READ_ONLY),
        trans1_TT_1_Cal_Point_Hi (READ_ONLY),
        trans1_TT_1_Sensor_Value_1,
        //trans1_TT_1_Sensor_Value_2,
        SEPARATOR,
        method_set_trans1_TT_1_cal_point_hi
    }
}


MENU OnlineDialog_trans1_TT_2_cal
{
    LABEL        [MC_cal_trd2];
    ITEMS
    {
        Page_trans1_TT_2_cal_para,
        Page_trans1_TT_2_cal_lo_point,
        Page_trans1_TT_2_cal_hi_point
    }
}

MENU Page_trans1_TT_2_cal_para
{
    LABEL     [MC_cal_para];
    ITEMS
    {
        trans1_TT_2_Cal_Unit,
        trans1_TT_2_lin_type,
        trans1_TT_2_input_range,
        SEPARATOR,
        method_set
    }
}

MENU Page_trans1_TT_2_cal_lo_point
{
    LABEL     [MC_cal_lo_point];
    ITEMS
    {
        trans1_TT_2_lower_sensor_limit (READ_ONLY),
        trans1_TT_2_Cal_Point_Lo (READ_ONLY),
        //trans1_TT_2_Sensor_Value_1,
        trans1_TT_2_Sensor_Value_2,
        SEPARATOR,
        method_set_trans1_TT_2_cal_point_lo
    }
}

MENU Page_trans1_TT_2_cal_hi_point
{
    LABEL     [MC_cal_hi_point];
    ITEMS
    {
        trans1_TT_2_upper_sensor_limit (READ_ONLY),
        trans1_TT_2_Cal_Point_Hi (READ_ONLY),
        //trans1_TT_2_Sensor_Value_1,
        trans1_TT_2_Sensor_Value_2,
        SEPARATOR,
        method_set_trans1_TT_2_cal_point_hi
    }
}

MENU OnlineWindow_simulation
{
    LABEL        [menu_dialog_simulation];
    ITEMS
    {
        Page_simulation_input_func1_AI_1,
        Page_simulation_input_func1_AI_2,
        Page_simulation_output_func1_AI_1,
        Page_simulation_output_func1_AI_2
    }
}

/*---------------------------------------------------------------------*/
/*    Menu: View                                                       */
/*---------------------------------------------------------------------*/
MENU Menu_S_View
{
    LABEL        [menu_View];
    ITEMS
    {
        OnlineWindow_display,
        SEPARATOR,
        OnlineWindow_yt,
        Menu_S_alarm,
        OnlineWindow_diagnosis
        SEPARATOR,
        std_Funktionsleiste,
        std_Statuszeile,
        SEPARATOR,
        std_Update     
    }
}

MENU OnlineWindow_display
{
    LABEL        [menu_dialog_display];
    ITEMS
    {
        Page_display_trans1_TT_1,
        Page_display_trans1_TT_2,
	    Page_display_func1_AI_1,
        Page_display_func1_AI_2
    }
}

MENU Page_display_trans1_TT_1
{
    LABEL        "Transducer 1";
    ITEMS
    {
        BarVal_trans1_TT_1_display_measure,
        Group_trans1_TT_1_display_Primary_Value,
        Group_trans1_TT_1_display_Secondary_Value
    }
}

MENU BarVal_trans1_TT_1_display_measure
{
    LABEL        [menu_dialog_display_measure];
    ITEMS
    {
        trans1_TT_1_primary_value,
        trans1_TT_1_lower_sensor_limit,
        trans1_TT_1_upper_sensor_limit
    }
}

MENU Group_trans1_TT_1_display_Primary_Value
{
    LABEL        [MC_Primary_Value];
    ITEMS
    {
        trans1_TT_1_primary_value,
        SEPARATOR,
        trans1_TT_1_primary_value_status_quality,
        trans1_TT_1_primary_value_status_limit
    }
}

MENU Group_trans1_TT_1_display_Secondary_Value
{
    LABEL        [MC_Secondary_Value];
    ITEMS
    {
        trans1_TT_1_secondary_value_1,
        trans1_TT_1_secondary_value_2,
        SEPARATOR,
        trans1_TT_1_input_fault_1,
        trans1_TT_1_input_fault_2,
        trans1_TT_1_rj_temp
    }
}

MENU Page_display_trans1_TT_2
{
    LABEL        "Transducer 2";
    ITEMS
    {
        BarVal_trans1_TT_2_display_measure,
        Group_trans1_TT_2_display_Primary_Value,
        Group_trans1_TT_2_display_Secondary_Value
    }
}

MENU BarVal_trans1_TT_2_display_measure
{
    LABEL        [menu_dialog_display_measure];
    ITEMS
    {
        trans1_TT_2_primary_value,
        trans1_TT_2_lower_sensor_limit,
        trans1_TT_2_upper_sensor_limit
    }
}

MENU Group_trans1_TT_2_display_Primary_Value
{
    LABEL        [MC_Primary_Value];
    ITEMS
    {
        trans1_TT_2_primary_value,
        SEPARATOR,
        trans1_TT_2_primary_value_status_quality,
        trans1_TT_2_primary_value_status_limit
    }
}

MENU Group_trans1_TT_2_display_Secondary_Value
{
    LABEL        [MC_Secondary_Value];
    ITEMS
    {
        trans1_TT_2_secondary_value_1,
        trans1_TT_2_secondary_value_2,
        SEPARATOR,
        trans1_TT_2_input_fault_1,
        trans1_TT_2_input_fault_2,
        trans1_TT_2_rj_temp
    }
}

MENU Menu_S_alarm
{
    LABEL        [menu_dialog_alarm];
    ITEMS
    {
        OnlineWindow_S_alarm_func1_AI_1,
        OnlineWindow_S_alarm_func1_AI_2
    }
}

MENU OnlineWindow_diagnosis
{
    LABEL        [menu_dialog_diagnosis];
    ITEMS
    {
        Page_diagnosis_general,
        Page_diagnosis_phys_block,
        Page_diagnosis_trans1_TT_1_block,
        Page_diagnosis_trans1_TT_2_block,
        Page_diagnosis_func1_AI_1,
        Page_diagnosis_func1_AI_2
    }
}

MENU Page_diagnosis_trans1_TT_1_block
{
    LABEL        [trans1_block];
    ITEMS
    {
        trans1_TT_1_blk_object,
        trans1_TT_1_blk_parent_class,
        trans1_TT_1_blk_class,
        trans1_TT_1_blk_dd_reference,
        trans1_TT_1_blk_dd_rev,
        trans1_TT_1_blk_profile,
        trans1_TT_1_blk_profile_rev,
        trans1_TT_1_st_rev,
        trans1_TT_1_actual_mode
    }
}

MENU Page_diagnosis_trans1_TT_2_block
{
    LABEL        [trans2_block];
    ITEMS
    {
        trans1_TT_2_blk_object,
        trans1_TT_2_blk_parent_class,
        trans1_TT_2_blk_class,
        trans1_TT_2_blk_dd_reference,
        trans1_TT_2_blk_dd_rev,
        trans1_TT_2_blk_profile,
        trans1_TT_2_blk_profile_rev,
        trans1_TT_2_st_rev,
        trans1_TT_2_actual_mode
    }
}



/***********************************************************************/
/*****    Table: Specialist    *****************************************/
/***********************************************************************/

MENU Table_Main_Specialist
{
    LABEL    [MC_Table_Main_Specialist_TT];
    ITEMS
    {
        Tab_s_info,
        Tab_s_trd,
        Tab_s_ai,
        Tab_s_lcd
    }
}

MENU Tab_s_info
{
    LABEL    [MC_Tab_info];
    ITEMS
    {
        Tab_s_manuf_info,       /* file Phys_Blk.inc */
        Tab_s_block_tag,
        Tab_s_get_info,         /* file Phys_Blk.inc */
        Tab_serial_numbers,
        Tab_device_revisions,   /* file Phys_Blk.inc */
        Tab_s_certificates      /* file Phys_Blk.inc */
    }
}

MENU Tab_s_block_tag
{
    LABEL    [MC_Tab_block_tag];
    ITEMS
    {
        phys_tag_desc,
        trans1_TT_1_tag_desc,
        trans1_TT_2_tag_desc,
        func1_AI_1_tag_desc,
        func1_AI_2_tag_desc
    }
}

MENU Tab_serial_numbers
{
    LABEL   [MC_Tab_serial_numbers];
    ITEMS
    {
        phys_device_ser_num   (READ_ONLY),
    }
}

MENU Tab_s_trd_1
{
    LABEL   [trans1];
    ITEMS
    {
        trans1_TT_1_st_rev,
        trans1_TT_1_lin_type,
        IF (trans1_TT_1_lin_type==0)
        { trans1_TT_1_input_range, }
        trans1_TT_1_primary_value_unit,
        trans1_TT_1_sensor_measure_type,
        trans1_TT_1_bias_1,
        IF (trans1_TT_1_sensor_measure_type != 0)
        { trans1_TT_1_bias_2,}
        IF ( (trans1_TT_1_lin_type == 102 || trans1_TT_1_lin_type == 105 || trans1_TT_1_lin_type == 240 || trans1_TT_1_lin_type == 127) || \
             (trans1_TT_1_lin_type == 0  && (trans1_TT_1_input_range == 128 || trans1_TT_1_input_range == 129))) 
        { trans1_TT_1_sensor_connection, }
        IF ((trans1_TT_1_lin_type == 128) || (trans1_TT_1_lin_type == 131) || 
            ((trans1_TT_1_lin_type >= 133) && (trans1_TT_1_lin_type <= 138)))
        { trans1_TT_1_rj_type, }
        trans1_TT_1_lower_sensor_limit,
        trans1_TT_1_upper_sensor_limit
    }
}

MENU Tab_s_trd_2
{
    LABEL   [trans2];
    ITEMS
    {
        trans1_TT_2_st_rev,
        trans1_TT_2_lin_type,
        IF (trans1_TT_2_lin_type==0)
        { trans1_TT_2_input_range, }
        trans1_TT_2_primary_value_unit,
        trans1_TT_2_sensor_measure_type,
        IF (trans1_TT_2_sensor_measure_type != 1)
        { trans1_TT_2_bias_1,}
        trans1_TT_2_bias_2,
        IF ( (trans1_TT_2_lin_type == 102 || trans1_TT_2_lin_type == 105 || trans1_TT_2_lin_type == 240 || trans1_TT_2_lin_type == 127) || \
             (trans1_TT_2_lin_type == 0  && (trans1_TT_2_input_range == 128 || trans1_TT_2_input_range == 129))) 
        { trans1_TT_2_sensor_connection, }
        IF ((trans1_TT_2_lin_type == 128) || (trans1_TT_2_lin_type == 131) || 
            ((trans1_TT_2_lin_type >= 133) && (trans1_TT_2_lin_type <= 138)))
        { trans1_TT_2_rj_type, }
        trans1_TT_2_lower_sensor_limit,
        trans1_TT_2_upper_sensor_limit
    }
}

MENU Tab_s_trd
{
    LABEL   "Tansducer (2)";
    ITEMS
    {
        Tab_s_trd_1,
        Tab_s_trd_2
    }
}

MENU Tab_s_ai
{
    LABEL   "Analog Input (2)";
    ITEMS
    {
        Tab_s_AI_1,
        Tab_s_AI_2
    }
}

/******************************************************************************/
/*****    Table: Maintenance    ***********************************************/
/******************************************************************************/
MENU Table_Main_Maintenance
{
    LABEL    [MC_Table_Main_Maintenance_TT];
    ITEMS
    {
        Tab_m_info,
        Tab_m_trd,
        Tab_m_AI,
        Tab_m_lcd
    }
}

MENU Tab_m_info
{
    LABEL    [MC_Tab_info];
    ITEMS
    {
        Tab_m_manuf_info,       /* file Phys_Blk.inc */
        Tab_m_block_tag,
        Tab_m_get_info,         /* file Phys_Blk.inc */
        Tab_serial_numbers,     /* file Phys_Blk.inc */
        Tab_device_revisions,   /* file Phys_Blk.inc */
        Tab_m_certificates      /* file Phys_Blk.inc */
    }
}

MENU Tab_m_block_tag
{
    LABEL    [MC_Tab_block_tag];
    ITEMS
    {
        phys_tag_desc  (READ_ONLY),
        trans1_TT_1_tag_desc  (READ_ONLY),
        trans1_TT_2_tag_desc  (READ_ONLY),
        func1_AI_1_tag_desc  (READ_ONLY),
        func1_AI_2_tag_desc  (READ_ONLY)
    }
}

MENU Tab_m_trd_1
{
    LABEL   [trans1];
    ITEMS
    {
        trans1_TT_1_st_rev,
        trans1_TT_1_lin_type  (READ_ONLY),
        trans1_TT_1_primary_value_unit  (READ_ONLY),
        trans1_TT_1_sensor_measure_type  (READ_ONLY),
        trans1_TT_1_input_range  (READ_ONLY),
        trans1_TT_1_lower_sensor_limit  (READ_ONLY),
        trans1_TT_1_upper_sensor_limit  (READ_ONLY)
    }
}

MENU Tab_m_trd_2
{
    LABEL   [trans2];
    ITEMS
    {
        trans1_TT_2_st_rev,
        trans1_TT_2_lin_type  (READ_ONLY),
        trans1_TT_2_primary_value_unit  (READ_ONLY),
        trans1_TT_2_sensor_measure_type  (READ_ONLY),
        trans1_TT_2_input_range  (READ_ONLY),
        trans1_TT_2_lower_sensor_limit  (READ_ONLY),
        trans1_TT_2_upper_sensor_limit  (READ_ONLY)
    }
}

MENU Tab_m_trd
{
    LABEL   "Tansducer (2)";
    ITEMS
    {
        Tab_m_trd_1,
        Tab_m_trd_2
    }
}

MENU Tab_m_AI
{
    LABEL   "Analog Input (2)";
    ITEMS
    {
        Tab_m_AI_1,
        Tab_m_AI_2
    }
}


METHOD std_NodeAddress
{
    LABEL        [menu_Device_NodeAddress];
    DEFINITION
    {
    }
}

METHOD std_LoadinDevice
{
    LABEL        [menu_Device_LoadinDevice];
    DEFINITION
    {
    }
}

METHOD std_LoadinPC
{
    LABEL        [menu_Device_LoadinPC];
    DEFINITION
    {
    }
}

METHOD std_Funktionsleiste
{
    LABEL        [menu_View_Toolbar];
    DEFINITION
    {
    }
}

METHOD std_Statuszeile
{
    LABEL        [menu_View_Statusbar];
    DEFINITION
    {
    }
}

METHOD std_Update
{
    LABEL        [menu_View_Update];
    DEFINITION
    {
    }
}

METHOD method_set
{
    LABEL        [MC_Write];
    HELP         [transfer_help];
    DEFINITION
    {
    }
}

METHOD method_tt_1_lin_type
{
    LABEL        [MC_method_tt_lin_type];
    DEFINITION
    {
        switch (trans1_TT_1_lin_type)
        {
        case 0:
            switch (trans1_TT_1_input_range)
            {
            case 0:
                if (trans1_TT_1_primary_value_unit != 1243) 
                {
                    trans1_TT_1_primary_value_unit = 1243;
                }
                trans1_TT_1_upper_sensor_limit = 100;
                trans1_TT_1_lower_sensor_limit = -100;
//                func1_AI_1_lo_lo_lim = -100;
//                func1_AI_1_lo_lim = -100;
//                func1_AI_1_hi_lim = 100;
//                func1_AI_1_hi_hi_lim = 100;
                break;

            case 128:
                if ((trans1_TT_1_primary_value_unit != 1281) || (trans1_TT_1_primary_value_unit != 1284))
                {
                    trans1_TT_1_primary_value_unit = 1281;
                }
                trans1_TT_1_upper_sensor_limit = 500;
                trans1_TT_1_lower_sensor_limit = 0;
//                func1_AI_1_lo_lo_lim = 0;
//                func1_AI_1_lo_lim = 0;
//                func1_AI_1_hi_lim = 500;
//                func1_AI_1_hi_hi_lim = 500;
                break;

            case 129:
                if ((trans1_TT_1_primary_value_unit != 1281) || (trans1_TT_1_primary_value_unit != 1284))
                {
                    trans1_TT_1_primary_value_unit = 1281;
                }
                trans1_TT_1_upper_sensor_limit = 4000;
                trans1_TT_1_lower_sensor_limit = 0;
//                func1_AI_1_lo_lo_lim = 0;
//                func1_AI_1_lo_lim = 0;
//                func1_AI_1_hi_lim = 4000;
//                func1_AI_1_hi_hi_lim = 4000;
                break;
            }
            break;

        case 102:
        case 105:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 850;
            trans1_TT_1_lower_sensor_limit = -200;
//            func1_AI_1_lo_lo_lim = -200;
//            func1_AI_1_lo_lim = -200;
//            func1_AI_1_hi_lim = 850;
//            func1_AI_1_hi_hi_lim = 850;
            break;

        case 240:
        case 127:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 150;
            trans1_TT_1_lower_sensor_limit = -50;
//            func1_AI_1_lo_lo_lim = -50;
//            func1_AI_1_lo_lim = -50;
//            func1_AI_1_hi_lim = 150;
//            func1_AI_1_hi_hi_lim = 150;
            break;

        case 128:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1820;
            trans1_TT_1_lower_sensor_limit = 0;
//            func1_AI_1_lo_lo_lim = 500;
//            func1_AI_1_lo_lim = 500;
//            func1_AI_1_hi_lim = 1820;
//            func1_AI_1_hi_hi_lim = 1820;
            break;

        case 131:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1000;
            trans1_TT_1_lower_sensor_limit = -270;
//            func1_AI_1_lo_lo_lim = -200;
//            func1_AI_1_lo_lim = -200;
//            func1_AI_1_hi_lim = 1000;
//            func1_AI_1_hi_hi_lim = 1000;
            break;

        case 133:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1200; 
            trans1_TT_1_lower_sensor_limit = -210; 
//            func1_AI_1_lo_lo_lim = -190;
//            func1_AI_1_lo_lim = -190;
//            func1_AI_1_hi_lim = 1200;
//            func1_AI_1_hi_hi_lim = 1200;
            break;

        case 134:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1372;
            trans1_TT_1_lower_sensor_limit = -270;
//            func1_AI_1_lo_lo_lim = -200;
//            func1_AI_1_lo_lim = -200;
//            func1_AI_1_hi_lim = 1372;
//            func1_AI_1_hi_hi_lim = 1372;
            break;

        case 135:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1300;
            trans1_TT_1_lower_sensor_limit = -270;
//            func1_AI_1_lo_lo_lim = -190;
//            func1_AI_1_lo_lim = -190;
//            func1_AI_1_hi_lim = 1300;
//            func1_AI_1_hi_hi_lim = 1300;
            break;

        case 136:
        case 137:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1768;
            trans1_TT_1_lower_sensor_limit = -50; 
//            func1_AI_1_lo_lo_lim = 0;
//            func1_AI_1_lo_lim = 0;
//            func1_AI_1_hi_lim = 1768;
//            func1_AI_1_hi_hi_lim = 1768;
            break;

        case 138:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 400; 
            trans1_TT_1_lower_sensor_limit = -270;
//            func1_AI_1_lo_lo_lim = -200;
//            func1_AI_1_lo_lim = -200;
//            func1_AI_1_hi_lim = 400;
//            func1_AI_1_hi_hi_lim = 400;
            break;
        }
        switch (ivar_value(trans1_TT_1_primary_value_unit))
        {
        case 1000:  //K ¶
            trans1_TT_1_upper_sensor_limit += 273.15;
            trans1_TT_1_lower_sensor_limit += 273.15;
//            func1_AI_1_lo_lo_lim +=  273.15;
//            func1_AI_1_lo_lim +=  273.15;
//            func1_AI_1_hi_lim += 273.15;
//            func1_AI_1_hi_hi_lim += 273.15;
            break;

        case 1001:  //C ¶
        case 1243:  //mV
        case 1281:  //Ohm
            trans1_TT_1_upper_sensor_limit = trans1_TT_1_upper_sensor_limit;
            trans1_TT_1_lower_sensor_limit = trans1_TT_1_lower_sensor_limit;
//            func1_AI_1_lo_lo_lim = func1_AI_1_lo_lo_lim;
//            func1_AI_1_lo_lim = func1_AI_1_lo_lim;
//            func1_AI_1_hi_lim = func1_AI_1_hi_lim;
//            func1_AI_1_hi_hi_lim = func1_AI_1_hi_hi_lim;
            break;

        case 1002:  //F ¶
            trans1_TT_1_upper_sensor_limit = trans1_TT_1_upper_sensor_limit*9/5+32;
            trans1_TT_1_lower_sensor_limit = trans1_TT_1_lower_sensor_limit*9/5+32;
//            func1_AI_1_lo_lo_lim = func1_AI_1_lo_lo_lim*9/5+32;
//            func1_AI_1_lo_lim = func1_AI_1_lo_lim*9/5+32;
//            func1_AI_1_hi_lim = func1_AI_1_hi_lim*9/5+32;
//            func1_AI_1_hi_hi_lim = func1_AI_1_hi_hi_lim*9/5+32;
            break;

        case 1003:  //R ¶
            trans1_TT_1_upper_sensor_limit = trans1_TT_1_upper_sensor_limit*9/5+32+495.69;
            trans1_TT_1_lower_sensor_limit = trans1_TT_1_lower_sensor_limit*9/5+32+495.69;
//            func1_AI_1_lo_lo_lim = func1_AI_1_lo_lo_lim*9/5+32+495.69;
//            func1_AI_1_lo_lim = func1_AI_1_lo_lim*9/5+32+495.69;
//            func1_AI_1_hi_lim = func1_AI_1_hi_lim*9/5+32+495.69;
//            func1_AI_1_hi_hi_lim = func1_AI_1_hi_hi_lim*9/5+32+495.69;
            break;

        case 1284:  //kOhm
            trans1_TT_1_upper_sensor_limit = trans1_TT_1_upper_sensor_limit/1000;
            trans1_TT_1_lower_sensor_limit = trans1_TT_1_lower_sensor_limit/1000;
//            func1_AI_1_lo_lo_lim = func1_AI_1_lo_lo_lim/1000;
//            func1_AI_1_lo_lim = func1_AI_1_lo_lim/1000;
//            func1_AI_1_hi_lim = func1_AI_1_hi_lim/1000;
//            func1_AI_1_hi_hi_lim = func1_AI_1_hi_hi_lim/1000;
           break;
        }
//        func1_AI_1_pv_lower_range_value = 0;
//        func1_AI_1_pv_upper_range_value = 100;
//        func1_AI_1_out_lower_range_value = 0;
//        func1_AI_1_out_upper_range_value = 100;
        if ((trans1_TT_1_lin_type != trans1_TT_2_lin_type) && 
            ((trans1_TT_1_sensor_measure_type == 128) ||
             (trans1_TT_1_sensor_measure_type == 129) ||
             (trans1_TT_1_sensor_measure_type == 192) ||
             (trans1_TT_2_sensor_measure_type == 128) ||
             (trans1_TT_2_sensor_measure_type == 129) ||
             (trans1_TT_2_sensor_measure_type == 192)))
        {
            trans1_TT_1_sensor_measure_type = 0;
            if (trans1_TT_2_sensor_measure_type != 0)
            {
                trans1_TT_2_sensor_measure_type = 1;
            }
        }
    }
}

METHOD method_TT_1_primary_value_unit
{
    LABEL        "method_TT_1_primary_value_unit";
    DEFINITION
    {
        if ((trans1_TT_1_primary_value_unit != trans1_TT_2_primary_value_unit) && 
            ((trans1_TT_1_sensor_measure_type == 128) ||
             (trans1_TT_1_sensor_measure_type == 129) ||
             (trans1_TT_1_sensor_measure_type == 192) ||
             (trans1_TT_2_sensor_measure_type == 128) ||
             (trans1_TT_2_sensor_measure_type == 129) ||
             (trans1_TT_2_sensor_measure_type == 192)))
        {
            trans1_TT_1_sensor_measure_type = 0;
            if (trans1_TT_2_sensor_measure_type != 0)
            {
                trans1_TT_2_sensor_measure_type = 1;
            }
        }
        save_values();
    }
}

METHOD method_TT_1_post_write_read_device_values
{
    DEFINITION
    {
        DELAY_TIME(1);
        ReadCommand(read_trans1_TT_1_bias_1);
        ReadCommand(read_trans1_TT_1_bias_2);
        ReadCommand(read_trans1_TT_1_upper_sensor_limit);
        ReadCommand(read_trans1_TT_1_lower_sensor_limit);
        save_values();
    }
}

METHOD method_tt_1_input_range
{
    LABEL        [MC_method_tt_input_range];
    DEFINITION
    {
        if (trans1_TT_1_lin_type == 0)
        {
            switch (trans1_TT_1_input_range)
            {
            case 0:
                if (trans1_TT_1_primary_value_unit != 1243) 
                {
                    trans1_TT_1_primary_value_unit = 1243;
                }
                trans1_TT_1_upper_sensor_limit = 100;
                trans1_TT_1_lower_sensor_limit = -100;
                break;

            case 128:
                if ((trans1_TT_1_primary_value_unit != 1281) || (trans1_TT_1_primary_value_unit != 1284))
                {
                    trans1_TT_1_primary_value_unit = 1281;
                }
                trans1_TT_1_upper_sensor_limit = 500;
                trans1_TT_1_lower_sensor_limit = 0;
                break;

            case 129:
                if ((trans1_TT_1_primary_value_unit != 1281) || (trans1_TT_1_primary_value_unit != 1284))
                {
                    trans1_TT_1_primary_value_unit = 1281;
                }
                trans1_TT_1_upper_sensor_limit = 4000;
                trans1_TT_1_lower_sensor_limit = 0;
                break;
            }
        }

        if ((trans1_TT_1_input_range != trans1_TT_2_input_range) && 
            ((trans1_TT_1_sensor_measure_type == 128) ||
             (trans1_TT_1_sensor_measure_type == 129) ||
             (trans1_TT_1_sensor_measure_type == 192) ||
             (trans1_TT_2_sensor_measure_type == 128) ||
             (trans1_TT_2_sensor_measure_type == 129) ||
             (trans1_TT_2_sensor_measure_type == 192)))
        {
            trans1_TT_1_sensor_measure_type = 0;
            if (trans1_TT_2_sensor_measure_type != 0)
            {
                trans1_TT_2_sensor_measure_type = 1;
            }
        }
    }
}

METHOD method_tt_2_lin_type
{
    LABEL        [MC_method_tt_lin_type];
    DEFINITION
    {
        switch (trans1_TT_2_lin_type)
        {
        case 0:
            switch (trans1_TT_2_input_range)
            {
            case 0:
                if (trans1_TT_2_primary_value_unit != 1243) 
                {
                    trans1_TT_2_primary_value_unit = 1243;
                }
                trans1_TT_2_upper_sensor_limit = 100;
                trans1_TT_2_lower_sensor_limit = -100;
//                func1_AI_2_lo_lo_lim = -100;
//                func1_AI_2_lo_lim = -100;
//                func1_AI_2_hi_lim = 100;
//                func1_AI_2_hi_hi_lim = 100;
                break;

            case 128:
                if ((trans1_TT_2_primary_value_unit != 1281) || (trans1_TT_2_primary_value_unit != 1284))
                {
                    trans1_TT_2_primary_value_unit = 1281;
                }
                trans1_TT_2_upper_sensor_limit = 500;
                trans1_TT_2_lower_sensor_limit = 0;
//                func1_AI_2_lo_lo_lim = 0;
//                func1_AI_2_lo_lim = 0;
//                func1_AI_2_hi_lim = 500;
//                func1_AI_2_hi_hi_lim = 500;
                break;

            case 129:
                if ((trans1_TT_2_primary_value_unit != 1281) || (trans1_TT_2_primary_value_unit != 1284))
                {
                    trans1_TT_2_primary_value_unit = 1281;
                }
                trans1_TT_2_upper_sensor_limit = 4000;
                trans1_TT_2_lower_sensor_limit = 0;
//                func1_AI_2_lo_lo_lim = 0;
//                func1_AI_2_lo_lim = 0;
//                func1_AI_2_hi_lim = 4000;
//                func1_AI_2_hi_hi_lim = 4000;
                break;
            }
            break;

        case 102:
        case 105:
            if ((trans1_TT_2_primary_value_unit == 1243) || (trans1_TT_2_primary_value_unit == 1281) || (trans1_TT_2_primary_value_unit == 1284))
            {
                trans1_TT_2_primary_value_unit = 1001;
            }
            trans1_TT_2_upper_sensor_limit = 850;
            trans1_TT_2_lower_sensor_limit = -200;
//            func1_AI_2_lo_lo_lim = -200;
//            func1_AI_2_lo_lim = -200;
//            func1_AI_2_hi_lim = 850;
//            func1_AI_2_hi_hi_lim = 850;
            break;

        case 240:
        case 127:
            if ((trans1_TT_2_primary_value_unit == 1243) || (trans1_TT_2_primary_value_unit == 1281) || (trans1_TT_2_primary_value_unit == 1284))
            {
                trans1_TT_2_primary_value_unit = 1001;
            }
            trans1_TT_2_upper_sensor_limit = 150;
            trans1_TT_2_lower_sensor_limit = -50;
//            func1_AI_2_lo_lo_lim = -50;
//            func1_AI_2_lo_lim = -50;
//            func1_AI_2_hi_lim = 150;
//            func1_AI_2_hi_hi_lim = 150;
            break;

        case 128:
            if ((trans1_TT_2_primary_value_unit == 1243) || (trans1_TT_2_primary_value_unit == 1281) || (trans1_TT_2_primary_value_unit == 1284))
            {
                trans1_TT_2_primary_value_unit = 1001;
            }
            trans1_TT_2_upper_sensor_limit = 1820;
            trans1_TT_2_lower_sensor_limit = 0;
//            func1_AI_2_lo_lo_lim = 500;
//            func1_AI_2_lo_lim = 500;
//            func1_AI_2_hi_lim = 1820;
//            func1_AI_2_hi_hi_lim = 1820;
            break;

        case 131:
            if ((trans1_TT_2_primary_value_unit == 1243) || (trans1_TT_2_primary_value_unit == 1281) || (trans1_TT_2_primary_value_unit == 1284))
            {
                trans1_TT_2_primary_value_unit = 1001;
            }
            trans1_TT_2_upper_sensor_limit = 1000;
            trans1_TT_2_lower_sensor_limit = -270;
//            func1_AI_2_lo_lo_lim = -200;
//            func1_AI_2_lo_lim = -200;
//            func1_AI_2_hi_lim = 1000;
//            func1_AI_2_hi_hi_lim = 1000;
            break;

        case 133:
            if ((trans1_TT_2_primary_value_unit == 1243) || (trans1_TT_2_primary_value_unit == 1281) || (trans1_TT_2_primary_value_unit == 1284))
            {
                trans1_TT_2_primary_value_unit = 1001;
            }
            trans1_TT_2_upper_sensor_limit = 1200; 
            trans1_TT_2_lower_sensor_limit = -210; 
//            func1_AI_2_lo_lo_lim = -190;
//            func1_AI_2_lo_lim = -190;
//            func1_AI_2_hi_lim = 1200;
//            func1_AI_2_hi_hi_lim = 1200;
            break;

        case 134:
            if ((trans1_TT_2_primary_value_unit == 1243) || (trans1_TT_2_primary_value_unit == 1281) || (trans1_TT_2_primary_value_unit == 1284))
            {
                trans1_TT_2_primary_value_unit = 1001;
            }
            trans1_TT_2_upper_sensor_limit = 1372;
            trans1_TT_2_lower_sensor_limit = -270;
//            func1_AI_2_lo_lo_lim = -200;
//            func1_AI_2_lo_lim = -200;
//            func1_AI_2_hi_lim = 1372;
//            func1_AI_2_hi_hi_lim = 1372;
            break;

        case 135:
            if ((trans1_TT_2_primary_value_unit == 1243) || (trans1_TT_2_primary_value_unit == 1281) || (trans1_TT_2_primary_value_unit == 1284))
            {
                trans1_TT_2_primary_value_unit = 1001;
            }
            trans1_TT_2_upper_sensor_limit = 1300;
            trans1_TT_2_lower_sensor_limit = -270;
//            func1_AI_2_lo_lo_lim = -190;
//            func1_AI_2_lo_lim = -190;
//            func1_AI_2_hi_lim = 1300;
//            func1_AI_2_hi_hi_lim = 1300;
            break;

        case 136:
        case 137:
            if ((trans1_TT_2_primary_value_unit == 1243) || (trans1_TT_2_primary_value_unit == 1281) || (trans1_TT_2_primary_value_unit == 1284))
            {
                trans1_TT_2_primary_value_unit = 1001;
            }
            trans1_TT_2_upper_sensor_limit = 1768;
            trans1_TT_2_lower_sensor_limit = -50; 
//            func1_AI_2_lo_lo_lim = 0;
//            func1_AI_2_lo_lim = 0;
//            func1_AI_2_hi_lim = 1768;
//            func1_AI_2_hi_hi_lim = 1768;
            break;

        case 138:
            if ((trans1_TT_2_primary_value_unit == 1243) || (trans1_TT_2_primary_value_unit == 1281) || (trans1_TT_2_primary_value_unit == 1284))
            {
                trans1_TT_2_primary_value_unit = 1001;
            }
            trans1_TT_2_upper_sensor_limit = 400; 
            trans1_TT_2_lower_sensor_limit = -270;
//            func1_AI_2_lo_lo_lim = -200;
//            func1_AI_2_lo_lim = -200;
//            func1_AI_2_hi_lim = 400;
//            func1_AI_2_hi_hi_lim = 400;
            break;

        }
        switch (trans1_TT_2_primary_value_unit)
        {
        case 1000:  //K ¶
            trans1_TT_2_upper_sensor_limit += 273.15;
            trans1_TT_2_lower_sensor_limit += 273.15;
//            func1_AI_2_lo_lo_lim +=  273.15;
//            func1_AI_2_lo_lim +=  273.15;
//            func1_AI_2_hi_lim += 273.15;
//            func1_AI_2_hi_hi_lim += 273.15;
            break;

        case 1001:  //C ¶
        case 1243:  //mV
        case 1281:  //Ohm
            trans1_TT_2_upper_sensor_limit = trans1_TT_2_upper_sensor_limit;
            trans1_TT_2_lower_sensor_limit = trans1_TT_2_lower_sensor_limit;
//            func1_AI_2_lo_lo_lim = func1_AI_2_lo_lo_lim;
//            func1_AI_2_lo_lim = func1_AI_2_lo_lim;
//            func1_AI_2_hi_lim = func1_AI_2_hi_lim;
//            func1_AI_2_hi_hi_lim = func1_AI_2_hi_hi_lim;
            break;

        case 1002:  //F ¶
            trans1_TT_2_upper_sensor_limit = trans1_TT_2_upper_sensor_limit*9/5+32;
            trans1_TT_2_lower_sensor_limit = trans1_TT_2_lower_sensor_limit*9/5+32;
//            func1_AI_2_lo_lo_lim = func1_AI_2_lo_lo_lim*9/5+32;
//            func1_AI_2_lo_lim = func1_AI_2_lo_lim*9/5+32;
//            func1_AI_2_hi_lim = func1_AI_2_hi_lim*9/5+32;
//            func1_AI_2_hi_hi_lim = func1_AI_2_hi_hi_lim*9/5+32;
            break;

        case 1003:  //R ¶
            trans1_TT_2_upper_sensor_limit = trans1_TT_2_upper_sensor_limit*9/5+32+495.69;
            trans1_TT_2_lower_sensor_limit = trans1_TT_2_lower_sensor_limit*9/5+32+495.69;
//            func1_AI_2_lo_lo_lim = func1_AI_2_lo_lo_lim*9/5+32+495.69;
//            func1_AI_2_lo_lim = func1_AI_2_lo_lim*9/5+32+495.69;
//            func1_AI_2_hi_lim = func1_AI_2_hi_lim*9/5+32+495.69;
//            func1_AI_2_hi_hi_lim = func1_AI_2_hi_hi_lim*9/5+32+495.69;
            break;

        case 1284:  //kOhm
            trans1_TT_2_upper_sensor_limit = trans1_TT_2_upper_sensor_limit/1000;
            trans1_TT_2_lower_sensor_limit = trans1_TT_2_lower_sensor_limit/1000;
//            func1_AI_2_lo_lo_lim = func1_AI_2_lo_lo_lim/1000;
//            func1_AI_2_lo_lim = func1_AI_2_lo_lim/1000;
//            func1_AI_2_hi_lim = func1_AI_2_hi_lim/1000;
//            func1_AI_2_hi_hi_lim = func1_AI_2_hi_hi_lim/1000;
           break;
        }
//        func1_AI_2_pv_lower_range_value = 0;
//        func1_AI_2_pv_upper_range_value = 100;
//        func1_AI_2_out_lower_range_value = 0;
//        func1_AI_2_out_upper_range_value = 100;
        if ((trans1_TT_1_lin_type != trans1_TT_2_lin_type) && 
            ((trans1_TT_1_sensor_measure_type == 128) ||
             (trans1_TT_1_sensor_measure_type == 129) ||
             (trans1_TT_1_sensor_measure_type == 192) ||
             (trans1_TT_2_sensor_measure_type == 128) ||
             (trans1_TT_2_sensor_measure_type == 129) ||
             (trans1_TT_2_sensor_measure_type == 192)))
        {
            if (trans1_TT_1_sensor_measure_type != 1)
            {
                trans1_TT_1_sensor_measure_type = 0;
            }
            trans1_TT_2_sensor_measure_type = 1;
        }
    }
}

METHOD method_TT_2_primary_value_unit
{
    LABEL        "method_TT_2_primary_value_unit";
    DEFINITION
    {
        if ((trans1_TT_1_primary_value_unit != trans1_TT_2_primary_value_unit) && 
            ((trans1_TT_1_sensor_measure_type == 128) ||
             (trans1_TT_1_sensor_measure_type == 129) ||
             (trans1_TT_1_sensor_measure_type == 192) ||
             (trans1_TT_2_sensor_measure_type == 128) ||
             (trans1_TT_2_sensor_measure_type == 129) ||
             (trans1_TT_2_sensor_measure_type == 192)))
        {
            if (trans1_TT_1_sensor_measure_type != 1)
            {
                trans1_TT_1_sensor_measure_type = 0;
            }
            trans1_TT_2_sensor_measure_type = 1;
        }
    }
}

METHOD method_TT_2_post_write_read_device_values
{
    DEFINITION
    {
        DELAY_TIME(1);
        ReadCommand(read_trans1_TT_2_bias_1);
        ReadCommand(read_trans1_TT_2_bias_2);
        ReadCommand(read_trans1_TT_2_upper_sensor_limit);
        ReadCommand(read_trans1_TT_2_lower_sensor_limit);
    }
}

METHOD method_tt_2_input_range
{
    LABEL        [MC_method_tt_input_range];
    DEFINITION
    {
        if (trans1_TT_2_lin_type == 0)
        {
            switch (trans1_TT_2_input_range)
            {
            case 0:
                if (trans1_TT_2_primary_value_unit != 1243) 
                {
                    trans1_TT_2_primary_value_unit = 1243;
                }
                trans1_TT_2_upper_sensor_limit = 100;
                trans1_TT_2_lower_sensor_limit = -100;
                break;

            case 128:
                if ((trans1_TT_2_primary_value_unit != 1281) || (trans1_TT_2_primary_value_unit != 1284))
                {
                    trans1_TT_2_primary_value_unit = 1281;
                }
                trans1_TT_2_upper_sensor_limit = 500;
                trans1_TT_2_lower_sensor_limit = 0;
                break;

            case 129:
                if ((trans1_TT_2_primary_value_unit != 1281) || (trans1_TT_2_primary_value_unit != 1284))
                {
                    trans1_TT_2_primary_value_unit = 1281;
                }
                trans1_TT_2_upper_sensor_limit = 4000;
                trans1_TT_2_lower_sensor_limit = 0;
                break;
            }
        }

        if ((trans1_TT_1_input_range != trans1_TT_2_input_range) && 
            ((trans1_TT_1_sensor_measure_type == 128) ||
             (trans1_TT_1_sensor_measure_type == 129) ||
             (trans1_TT_1_sensor_measure_type == 192) ||
             (trans1_TT_2_sensor_measure_type == 128) ||
             (trans1_TT_2_sensor_measure_type == 129) ||
             (trans1_TT_2_sensor_measure_type == 192)))
        {
            if (trans1_TT_1_sensor_measure_type != 1)
            {
                trans1_TT_1_sensor_measure_type = 0;
            }
            trans1_TT_2_sensor_measure_type = 1;
        }
    }
}

METHOD method_pre_write_phys_write_locking
{
    LABEL   [method_pre_write_phys_write_locking];
    DEFINITION
    {
        int ret;
        ReadCommand (read_phys_write_locking);
        if ( phys_write_locking == 0 )
        {
            ret = ACKNOWLEDGE([label_DeviceIsWriteProtected]);
            if (ret) process_abort();
        }
    }
}

METHOD method_write_trans1_TT_1_sensor_measure_type
{
    LABEL [MC_Write];
    DEFINITION
    {
        if ((trans1_TT_2_sensor_measure_type == 128) || 
            (trans1_TT_2_sensor_measure_type == 129) || 
            (trans1_TT_2_sensor_measure_type == 192))
        {
            if (trans1_TT_1_lin_type != trans1_TT_2_lin_type)
            {
                ACKNOWLEDGE("Lin Type different.");  
            } 
            else if (trans1_TT_1_input_range != trans1_TT_2_input_range)
            {
                ACKNOWLEDGE("Input Range different.");  
            } 
            else if (trans1_TT_1_primary_value_unit != trans1_TT_2_primary_value_unit)
            {
                ACKNOWLEDGE("Primary value unit different.");  
            }
            else
            {
                WriteCommand(write_trans1_TT_1_sensor_measure_type);
                ReadCommand(read_trans1_TT_1_sensor_measure_type);
            }
        }
        else
        {
            WriteCommand(write_trans1_TT_1_sensor_measure_type);
            ReadCommand(read_trans1_TT_1_sensor_measure_type);
        }
    }
}

METHOD method_write_trans1_TT_1_Sensor_type
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_TT_1_lin_type);
        ReadCommand(read_trans1_TT_1_lin_type);

        if (trans1_TT_1_lin_type == 0)
        {
            WriteCommand(write_trans1_TT_1_input_range);
            ReadCommand(read_trans1_TT_1_input_range);
        }

        switch (trans1_TT_1_lin_type)
        {
        case 0:
            switch (trans1_TT_1_input_range)
            {
            case 0:
                trans1_TT_1_primary_value_unit = 1243;
                trans1_TT_1_upper_sensor_limit = 100;
                trans1_TT_1_lower_sensor_limit = -100;
//                func1_AI_1_lo_lo_lim = -100;
//                func1_AI_1_lo_lim = -100;
//                func1_AI_1_hi_lim = 100;
//                func1_AI_1_hi_hi_lim = 100;
                break;

            case 128:
                trans1_TT_1_primary_value_unit = 1281;
                trans1_TT_1_upper_sensor_limit = 500;
                trans1_TT_1_lower_sensor_limit = 0;
//                func1_AI_1_lo_lo_lim = 0;
//                func1_AI_1_lo_lim = 0;
//                func1_AI_1_hi_lim = 500;
//                func1_AI_1_hi_hi_lim = 500;
                break;

            case 129:
                trans1_TT_1_primary_value_unit = 1281;
                trans1_TT_1_upper_sensor_limit = 4000;
                trans1_TT_1_lower_sensor_limit = 0;
//                func1_AI_1_lo_lo_lim = 0;
//                func1_AI_1_lo_lim = 0;
//                func1_AI_1_hi_lim = 4000;
//                func1_AI_1_hi_hi_lim = 4000;
                break;
            }
            break;

        case 102:
        case 105:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 850;
            trans1_TT_1_lower_sensor_limit = -200;
//            func1_AI_1_lo_lo_lim = -200;
//            func1_AI_1_lo_lim = -200;
//            func1_AI_1_hi_lim = 850;
//            func1_AI_1_hi_hi_lim = 850;
            break;

        case 240:
        case 127:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 150;
            trans1_TT_1_lower_sensor_limit = -50;
//            func1_AI_1_lo_lo_lim = -50;
//            func1_AI_1_lo_lim = -50;
//            func1_AI_1_hi_lim = 150;
//            func1_AI_1_hi_hi_lim = 150;
            break;

        case 128:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1820;
            trans1_TT_1_lower_sensor_limit = 0;
//            func1_AI_1_lo_lo_lim = 500;
//            func1_AI_1_lo_lim = 500;
//            func1_AI_1_hi_lim = 1820;
//            func1_AI_1_hi_hi_lim = 1820;
            break;

        case 131:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1000;
            trans1_TT_1_lower_sensor_limit = -270;
//            func1_AI_1_lo_lo_lim = -200;
//            func1_AI_1_lo_lim = -200;
//            func1_AI_1_hi_lim = 1000;
//            func1_AI_1_hi_hi_lim = 1000;
            break;

        case 133:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1200; 
            trans1_TT_1_lower_sensor_limit = -210; 
//            func1_AI_1_lo_lo_lim = -190;
//            func1_AI_1_lo_lim = -190;
//            func1_AI_1_hi_lim = 1200;
//            func1_AI_1_hi_hi_lim = 1200;
            break;

        case 134:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1372;
            trans1_TT_1_lower_sensor_limit = -270;
//            func1_AI_1_lo_lo_lim = -200;
//            func1_AI_1_lo_lim = -200;
//            func1_AI_1_hi_lim = 1372;
//            func1_AI_1_hi_hi_lim = 1372;
            break;

        case 135:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1300;
            trans1_TT_1_lower_sensor_limit = -270;
//            func1_AI_1_lo_lo_lim = -190;
//            func1_AI_1_lo_lim = -190;
//            func1_AI_1_hi_lim = 1300;
//            func1_AI_1_hi_hi_lim = 1300;
            break;

        case 136:
        case 137:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1768;
            trans1_TT_1_lower_sensor_limit = -50; 
//            func1_AI_1_lo_lo_lim = 0;
//            func1_AI_1_lo_lim = 0;
//            func1_AI_1_hi_lim = 1768;
//            func1_AI_1_hi_hi_lim = 1768;
            break;

        case 138:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 400; 
            trans1_TT_1_lower_sensor_limit = -270;
//            func1_AI_1_lo_lo_lim = -200;
//            func1_AI_1_lo_lim = -200;
//            func1_AI_1_hi_lim = 400;
//            func1_AI_1_hi_hi_lim = 400;
            break;
        }

        switch (ivar_value(trans1_TT_1_primary_value_unit))
        {
        case 1000:  //K ¶
            trans1_TT_1_upper_sensor_limit += 273.15;
            trans1_TT_1_lower_sensor_limit += 273.15;
//            func1_AI_1_lo_lo_lim +=  273.15;
//            func1_AI_1_lo_lim +=  273.15;
//            func1_AI_1_hi_lim += 273.15;
//            func1_AI_1_hi_hi_lim += 273.15;
            break;

        case 1001:  //C ¶
        case 1243:  //mV
        case 1281:  //Ohm
            trans1_TT_1_upper_sensor_limit = trans1_TT_1_upper_sensor_limit;
            trans1_TT_1_lower_sensor_limit = trans1_TT_1_lower_sensor_limit;
//            func1_AI_1_lo_lo_lim = func1_AI_1_lo_lo_lim;
//            func1_AI_1_lo_lim = func1_AI_1_lo_lim;
//            func1_AI_1_hi_lim = func1_AI_1_hi_lim;
//            func1_AI_1_hi_hi_lim = func1_AI_1_hi_hi_lim;
            break;

        case 1002:  //F ¶
            trans1_TT_1_upper_sensor_limit = trans1_TT_1_upper_sensor_limit*9/5+32;
            trans1_TT_1_lower_sensor_limit = trans1_TT_1_lower_sensor_limit*9/5+32;
//            func1_AI_1_lo_lo_lim = func1_AI_1_lo_lo_lim*9/5+32;
//            func1_AI_1_lo_lim = func1_AI_1_lo_lim*9/5+32;
//            func1_AI_1_hi_lim = func1_AI_1_hi_lim*9/5+32;
//            func1_AI_1_hi_hi_lim = func1_AI_1_hi_hi_lim*9/5+32;
            break;

        case 1003:  //R ¶
            trans1_TT_1_upper_sensor_limit = trans1_TT_1_upper_sensor_limit*9/5+32+495.69;
            trans1_TT_1_lower_sensor_limit = trans1_TT_1_lower_sensor_limit*9/5+32+495.69;
//            func1_AI_1_lo_lo_lim = func1_AI_1_lo_lo_lim*9/5+32+495.69;
//            func1_AI_1_lo_lim = func1_AI_1_lo_lim*9/5+32+495.69;
//            func1_AI_1_hi_lim = func1_AI_1_hi_lim*9/5+32+495.69;
//            func1_AI_1_hi_hi_lim = func1_AI_1_hi_hi_lim*9/5+32+495.69;
            break;

        case 1284:  //kOhm
            trans1_TT_1_upper_sensor_limit = trans1_TT_1_upper_sensor_limit/1000;
            trans1_TT_1_lower_sensor_limit = trans1_TT_1_lower_sensor_limit/1000;
//            func1_AI_1_lo_lo_lim = func1_AI_1_lo_lo_lim/1000;
//            func1_AI_1_lo_lim = func1_AI_1_lo_lim/1000;
//            func1_AI_1_hi_lim = func1_AI_1_hi_lim/1000;
//            func1_AI_1_hi_hi_lim = func1_AI_1_hi_hi_lim/1000;
           break;
        }

        WriteCommand(write_trans1_TT_1_primary_value_unit);
//        WriteCommand(write_func1_AI_1_lo_lo_lim);
//        WriteCommand(write_func1_AI_1_lo_lim);
//        WriteCommand(write_func1_AI_1_hi_lim);
//        WriteCommand(write_func1_AI_1_hi_hi_lim);

        ReadCommand(read_trans1_TT_1_primary_value_unit);
        ReadCommand(read_trans1_TT_1_upper_sensor_limit);
        ReadCommand(read_trans1_TT_1_lower_sensor_limit);
//        ReadCommand(read_func1_AI_1_lo_lo_lim);
//        ReadCommand(read_func1_AI_1_lo_lim);
//        ReadCommand(read_func1_AI_1_hi_lim);
//        ReadCommand(read_func1_AI_1_hi_hi_lim);

        if (((trans1_TT_1_lin_type != trans1_TT_2_lin_type) ||
             (trans1_TT_1_input_range != trans1_TT_2_input_range)) && 
            ((trans1_TT_1_sensor_measure_type == 128) ||
             (trans1_TT_1_sensor_measure_type == 129) ||
             (trans1_TT_1_sensor_measure_type == 192) ||
             (trans1_TT_2_sensor_measure_type == 128) ||
             (trans1_TT_2_sensor_measure_type == 129) ||
             (trans1_TT_2_sensor_measure_type == 192)))
        {
            trans1_TT_1_sensor_measure_type = 0;
            if (trans1_TT_2_sensor_measure_type != 0)
            {
                trans1_TT_2_sensor_measure_type = 1;
            }
            WriteCommand(write_trans1_TT_1_sensor_measure_type);
            WriteCommand(write_trans1_TT_2_sensor_measure_type);
            ReadCommand(read_trans1_TT_1_sensor_measure_type);
            ReadCommand(read_trans1_TT_2_sensor_measure_type);
        }
    }
}

METHOD method_write_trans1_TT_1_sensor_connection
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_TT_1_sensor_connection);
        ReadCommand(read_trans1_TT_1_sensor_connection);
    }
}

METHOD method_write_trans1_TT_1_rj_type
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_TT_1_rj_type);
        ReadCommand(read_trans1_TT_1_rj_type);
    }
}

METHOD method_write_trans1_TT_1_primary_value_unit
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_TT_1_primary_value_unit);
        ReadCommand(read_trans1_TT_1_primary_value_unit);
    }
}

METHOD method_write_trans1_TT_1_bias_1
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_TT_1_bias_1);
        ReadCommand(read_trans1_TT_1_bias_1);
    }
}

METHOD method_write_trans1_TT_1_bias_2
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_TT_1_bias_2);
        ReadCommand(read_trans1_TT_1_bias_2);
    }
}

METHOD method_write_trans1_TT_2_sensor_measure_type
{
    LABEL [MC_Write];
    DEFINITION
    {
        if ((trans1_TT_2_sensor_measure_type == 128) || 
            (trans1_TT_2_sensor_measure_type == 129) || 
            (trans1_TT_2_sensor_measure_type == 192))
        {
            if (trans1_TT_1_lin_type != trans1_TT_2_lin_type)
            {
                ACKNOWLEDGE("Lin Type different.");  
            } 
            else if (trans1_TT_1_input_range != trans1_TT_2_input_range)
            {
                ACKNOWLEDGE("Input Range different.");  
            } 
            else if (trans1_TT_1_primary_value_unit != trans1_TT_2_primary_value_unit)
            {
                ACKNOWLEDGE("Primary value unit different.");  
            }
            else
            {
                WriteCommand(write_trans1_TT_2_sensor_measure_type);
                ReadCommand(read_trans1_TT_2_sensor_measure_type);
            }
        }
        else
        {
            WriteCommand(write_trans1_TT_2_sensor_measure_type);
            ReadCommand(read_trans1_TT_2_sensor_measure_type);
        }
    }
}

METHOD method_write_trans1_TT_2_Sensor_type
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_TT_2_lin_type);
        ReadCommand(read_trans1_TT_2_lin_type);

        if (trans1_TT_2_lin_type == 0)
        {
            WriteCommand(write_trans1_TT_2_input_range);
            ReadCommand(read_trans1_TT_2_input_range);
        }

        switch (trans1_TT_2_lin_type)
        {
        case 0:
            switch (trans1_TT_2_input_range)
            {
            case 0:
                trans1_TT_2_primary_value_unit = 1243;
                trans1_TT_2_upper_sensor_limit = 100;
                trans1_TT_2_lower_sensor_limit = -100;
//                func1_AI_2_lo_lo_lim = -100;
//                func1_AI_2_lo_lim = -100;
//                func1_AI_2_hi_lim = 100;
//                func1_AI_2_hi_hi_lim = 100;
                break;

            case 128:
                trans1_TT_2_primary_value_unit = 1281;
                trans1_TT_2_upper_sensor_limit = 500;
                trans1_TT_2_lower_sensor_limit = 0;
//                func1_AI_2_lo_lo_lim = 0;
//                func1_AI_2_lo_lim = 0;
//                func1_AI_2_hi_lim = 500;
//                func1_AI_2_hi_hi_lim = 500;
                break;

            case 129:
                trans1_TT_2_primary_value_unit = 1281;
                trans1_TT_2_upper_sensor_limit = 4000;
                trans1_TT_2_lower_sensor_limit = 0;
//                func1_AI_2_lo_lo_lim = 0;
//                func1_AI_2_lo_lim = 0;
//                func1_AI_2_hi_lim = 4000;
//                func1_AI_2_hi_hi_lim = 4000;
                break;
            }
            break;

        case 102:
        case 105:
            if ((trans1_TT_2_primary_value_unit == 1243) || (trans1_TT_2_primary_value_unit == 1281) || (trans1_TT_2_primary_value_unit == 1284))
            {
                trans1_TT_2_primary_value_unit = 1001;
            }
            trans1_TT_2_upper_sensor_limit = 850;
            trans1_TT_2_lower_sensor_limit = -200;
//            func1_AI_2_lo_lo_lim = -200;
//            func1_AI_2_lo_lim = -200;
//            func1_AI_2_hi_lim = 850;
//            func1_AI_2_hi_hi_lim = 850;
            break;

        case 240:
        case 127:
            if ((trans1_TT_2_primary_value_unit == 1243) || (trans1_TT_2_primary_value_unit == 1281) || (trans1_TT_2_primary_value_unit == 1284))
            {
                trans1_TT_2_primary_value_unit = 1001;
            }
            trans1_TT_2_upper_sensor_limit = 150;
            trans1_TT_2_lower_sensor_limit = -50;
//            func1_AI_2_lo_lo_lim = -50;
//            func1_AI_2_lo_lim = -50;
//            func1_AI_2_hi_lim = 150;
//            func1_AI_2_hi_hi_lim = 150;
            break;

        case 128:
            if ((trans1_TT_2_primary_value_unit == 1243) || (trans1_TT_2_primary_value_unit == 1281) || (trans1_TT_2_primary_value_unit == 1284))
            {
                trans1_TT_2_primary_value_unit = 1001;
            }
            trans1_TT_2_upper_sensor_limit = 1820;
            trans1_TT_2_lower_sensor_limit = 0;
//            func1_AI_2_lo_lo_lim = 500;
//            func1_AI_2_lo_lim = 500;
//            func1_AI_2_hi_lim = 1820;
//            func1_AI_2_hi_hi_lim = 1820;
            break;

        case 131:
            if ((trans1_TT_2_primary_value_unit == 1243) || (trans1_TT_2_primary_value_unit == 1281) || (trans1_TT_2_primary_value_unit == 1284))
            {
                trans1_TT_2_primary_value_unit = 1001;
            }
            trans1_TT_2_upper_sensor_limit = 1000;
            trans1_TT_2_lower_sensor_limit = -270;
//            func1_AI_2_lo_lo_lim = -200;
//            func1_AI_2_lo_lim = -200;
//            func1_AI_2_hi_lim = 1000;
//            func1_AI_2_hi_hi_lim = 1000;
            break;

        case 133:
            if ((trans1_TT_2_primary_value_unit == 1243) || (trans1_TT_2_primary_value_unit == 1281) || (trans1_TT_2_primary_value_unit == 1284))
            {
                trans1_TT_2_primary_value_unit = 1001;
            }
            trans1_TT_2_upper_sensor_limit = 1200; 
            trans1_TT_2_lower_sensor_limit = -210; 
//            func1_AI_2_lo_lo_lim = -190;
//            func1_AI_2_lo_lim = -190;
//            func1_AI_2_hi_lim = 1200;
//            func1_AI_2_hi_hi_lim = 1200;
            break;

        case 134:
            if ((trans1_TT_2_primary_value_unit == 1243) || (trans1_TT_2_primary_value_unit == 1281) || (trans1_TT_2_primary_value_unit == 1284))
            {
                trans1_TT_2_primary_value_unit = 1001;
            }
            trans1_TT_2_upper_sensor_limit = 1372;
            trans1_TT_2_lower_sensor_limit = -270;
//            func1_AI_2_lo_lo_lim = -200;
//            func1_AI_2_lo_lim = -200;
//            func1_AI_2_hi_lim = 1372;
//            func1_AI_2_hi_hi_lim = 1372;
            break;

        case 135:
            if ((trans1_TT_2_primary_value_unit == 1243) || (trans1_TT_2_primary_value_unit == 1281) || (trans1_TT_2_primary_value_unit == 1284))
            {
                trans1_TT_2_primary_value_unit = 1001;
            }
            trans1_TT_2_upper_sensor_limit = 1300;
            trans1_TT_2_lower_sensor_limit = -270;
//            func1_AI_2_lo_lo_lim = -190;
//            func1_AI_2_lo_lim = -190;
//            func1_AI_2_hi_lim = 1300;
//            func1_AI_2_hi_hi_lim = 1300;
            break;

        case 136:
        case 137:
            if ((trans1_TT_2_primary_value_unit == 1243) || (trans1_TT_2_primary_value_unit == 1281) || (trans1_TT_2_primary_value_unit == 1284))
            {
                trans1_TT_2_primary_value_unit = 1001;
            }
            trans1_TT_2_upper_sensor_limit = 1768;
            trans1_TT_2_lower_sensor_limit = -50; 
//            func1_AI_2_lo_lo_lim = 0;
//            func1_AI_2_lo_lim = 0;
//            func1_AI_2_hi_lim = 1768;
//            func1_AI_2_hi_hi_lim = 1768;
            break;

        case 138:
            if ((trans1_TT_2_primary_value_unit == 1243) || (trans1_TT_2_primary_value_unit == 1281) || (trans1_TT_2_primary_value_unit == 1284))
            {
                trans1_TT_2_primary_value_unit = 1001;
            }
            trans1_TT_2_upper_sensor_limit = 400; 
            trans1_TT_2_lower_sensor_limit = -270;
//            func1_AI_2_lo_lo_lim = -200;
//            func1_AI_2_lo_lim = -200;
//            func1_AI_2_hi_lim = 400;
//            func1_AI_2_hi_hi_lim = 400;
            break;

        }
        switch (trans1_TT_2_primary_value_unit)
        {
        case 1000:  //K ¶
            trans1_TT_2_upper_sensor_limit += 273.15;
            trans1_TT_2_lower_sensor_limit += 273.15;
//            func1_AI_2_lo_lo_lim +=  273.15;
//            func1_AI_2_lo_lim +=  273.15;
//            func1_AI_2_hi_lim += 273.15;
//            func1_AI_2_hi_hi_lim += 273.15;
            break;

        case 1001:  //C ¶
        case 1243:  //mV
        case 1281:  //Ohm
            trans1_TT_2_upper_sensor_limit = trans1_TT_2_upper_sensor_limit;
            trans1_TT_2_lower_sensor_limit = trans1_TT_2_lower_sensor_limit;
//            func1_AI_2_lo_lo_lim = func1_AI_2_lo_lo_lim;
//            func1_AI_2_lo_lim = func1_AI_2_lo_lim;
//            func1_AI_2_hi_lim = func1_AI_2_hi_lim;
//            func1_AI_2_hi_hi_lim = func1_AI_2_hi_hi_lim;
            break;

        case 1002:  //F ¶
            trans1_TT_2_upper_sensor_limit = trans1_TT_2_upper_sensor_limit*9/5+32;
            trans1_TT_2_lower_sensor_limit = trans1_TT_2_lower_sensor_limit*9/5+32;
//            func1_AI_2_lo_lo_lim = func1_AI_2_lo_lo_lim*9/5+32;
//            func1_AI_2_lo_lim = func1_AI_2_lo_lim*9/5+32;
//            func1_AI_2_hi_lim = func1_AI_2_hi_lim*9/5+32;
//            func1_AI_2_hi_hi_lim = func1_AI_2_hi_hi_lim*9/5+32;
            break;

        case 1003:  //R ¶
            trans1_TT_2_upper_sensor_limit = trans1_TT_2_upper_sensor_limit*9/5+32+495.69;
            trans1_TT_2_lower_sensor_limit = trans1_TT_2_lower_sensor_limit*9/5+32+495.69;
//            func1_AI_2_lo_lo_lim = func1_AI_2_lo_lo_lim*9/5+32+495.69;
//            func1_AI_2_lo_lim = func1_AI_2_lo_lim*9/5+32+495.69;
//            func1_AI_2_hi_lim = func1_AI_2_hi_lim*9/5+32+495.69;
//            func1_AI_2_hi_hi_lim = func1_AI_2_hi_hi_lim*9/5+32+495.69;
            break;

        case 1284:  //kOhm
            trans1_TT_2_upper_sensor_limit = trans1_TT_2_upper_sensor_limit/1000;
            trans1_TT_2_lower_sensor_limit = trans1_TT_2_lower_sensor_limit/1000;
//            func1_AI_2_lo_lo_lim = func1_AI_2_lo_lo_lim/1000;
//            func1_AI_2_lo_lim = func1_AI_2_lo_lim/1000;
//            func1_AI_2_hi_lim = func1_AI_2_hi_lim/1000;
//            func1_AI_2_hi_hi_lim = func1_AI_2_hi_hi_lim/1000;
           break;
        }

        WriteCommand(write_trans1_TT_2_primary_value_unit);
//        WriteCommand(write_func1_AI_2_lo_lo_lim);
//        WriteCommand(write_func1_AI_2_lo_lim);
//        WriteCommand(write_func1_AI_2_hi_lim);
//        WriteCommand(write_func1_AI_2_hi_hi_lim);

        ReadCommand(read_trans1_TT_2_primary_value_unit);
        ReadCommand(read_trans1_TT_2_upper_sensor_limit);
        ReadCommand(read_trans1_TT_2_lower_sensor_limit);
//        ReadCommand(read_func1_AI_2_lo_lo_lim);
//        ReadCommand(read_func1_AI_2_lo_lim);
//        ReadCommand(read_func1_AI_2_hi_lim);
//        ReadCommand(read_func1_AI_2_hi_hi_lim);

        if (((trans1_TT_1_lin_type != trans1_TT_2_lin_type) ||
             (trans1_TT_1_input_range != trans1_TT_2_input_range)) && 
            ((trans1_TT_1_sensor_measure_type == 128) ||
             (trans1_TT_1_sensor_measure_type == 129) ||
             (trans1_TT_1_sensor_measure_type == 192) ||
             (trans1_TT_2_sensor_measure_type == 128) ||
             (trans1_TT_2_sensor_measure_type == 129) ||
             (trans1_TT_2_sensor_measure_type == 192)))
        {
            if (trans1_TT_1_sensor_measure_type != 1)
            {
                trans1_TT_1_sensor_measure_type = 0;
            }
            trans1_TT_2_sensor_measure_type = 1;
            WriteCommand(write_trans1_TT_1_sensor_measure_type);
            WriteCommand(write_trans1_TT_2_sensor_measure_type);
            ReadCommand(read_trans1_TT_1_sensor_measure_type);
            ReadCommand(read_trans1_TT_2_sensor_measure_type);
        }
    }
}

METHOD method_write_trans1_TT_2_sensor_connection
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_TT_2_sensor_connection);
        ReadCommand(read_trans1_TT_2_sensor_connection);
    }
}

METHOD method_write_trans1_TT_2_rj_type
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_TT_2_rj_type);
        ReadCommand(read_trans1_TT_2_rj_type);
    }
}

METHOD method_write_trans1_TT_2_primary_value_unit
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_TT_2_primary_value_unit);
        ReadCommand(read_trans1_TT_2_primary_value_unit);
    }
}

METHOD method_write_trans1_TT_2_bias_1
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_TT_2_bias_1);
        ReadCommand(read_trans1_TT_2_bias_1);
    }
}

METHOD method_write_trans1_TT_2_bias_2
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_TT_2_bias_2);
        ReadCommand(read_trans1_TT_2_bias_2);
    }
}

METHOD method_set_trans1_TT_1_two_Wires_Comp
{
    LABEL        [MC_Write];
    DEFINITION
    {
        int fValue;
        //ReadCommand(func1_AI_1_simulation_enabled);
        if (func1_AI_1_simulation_enabled == 0)        //0 = [off]
        {
            //WriteCommand (write_trans1_TT_1_Channel);
            trans1_TT_1_Two_Wires_Comp = 1;
            WriteCommand (write_trans1_TT_1_Two_Wires_Comp);
            fValue = 1;
            while(fValue = 0)
            {
                ReadCommand (read_trans1_TT_1_two_Wires_Comp);
                fValue = ivar_value(trans1_TT_1_Two_Wires_Comp);
            }
            if (fValue == 0) PUT_MESSAGE("Finished.");
        }
        else
        {
            ACKNOWLEDGE("Function not permitted during simulation");  
        }

    }
}

METHOD method_set_trans1_TT_1_cal_point_lo
{
    LABEL        [MC_Start];
    DEFINITION
    {
        int ret,fValue;

        if (func1_AI_1_simulation_enabled == 0)        //0 = [off]
        {
            ret = GET_DEV_VAR_VALUE("Enter applied temperature value", trans1_TT_1_Cal_Point_Lo);
            fValue = trans1_TT_1_Cal_Point_Lo;

            if (ret < 0)
            {
                process_abort();
            }

            WriteCommand (write_trans1_TT_1_Cal_Point_Lo);
            ReadCommand (read_trans1_TT_1_Cal_Point_Lo);
        }
        else
        {
            ACKNOWLEDGE("Function not permitted during simulation");  
        }

    }
}

METHOD method_set_trans1_TT_1_cal_point_hi
{
    LABEL        [MC_Start];
    DEFINITION
    {
        int ret,fValue;

        if (func1_AI_1_simulation_enabled == 0)        //0 = [off]
        {
            ret = GET_DEV_VAR_VALUE("Enter applied temperature value", trans1_TT_1_Cal_Point_Hi);
            fValue = trans1_TT_1_Cal_Point_Hi;

            if (ret < 0)
            {
                process_abort();
            }

            WriteCommand (write_trans1_TT_1_Cal_Point_Hi);
            ReadCommand (read_trans1_TT_1_Cal_Point_Hi);
        }
        else
        {
            ACKNOWLEDGE("Function not permitted during simulation");  
        }

    }
}

METHOD method_set_trans1_TT_2_two_Wires_Comp
{
    LABEL        [MC_Write];
    DEFINITION
    {
        int fValue;
        //ReadCommand(func1_AI_2_simulation_enabled);
        if (func1_AI_2_simulation_enabled == 0)        //0 = [off]
        {
            //WriteCommand (write_trans1_TT_2_Channel);
            trans1_TT_2_Two_Wires_Comp = 1;
            WriteCommand (write_trans1_TT_2_Two_Wires_Comp);
            fValue = 1;
            while(fValue = 0)
            {
                ReadCommand (read_trans1_TT_2_two_Wires_Comp);
                fValue = ivar_value(trans1_TT_2_Two_Wires_Comp);
            }
            if (fValue == 0) PUT_MESSAGE("Finished.");
        }
        else
        {
            ACKNOWLEDGE("Function not permitted during simulation");  
        }

    }
}

METHOD method_set_trans1_TT_2_cal_point_lo
{
    LABEL        [MC_Start];
    DEFINITION
    {
        int ret,fValue;

        if (func1_AI_2_simulation_enabled == 0)        //0 = [off]
        {
            ret = GET_DEV_VAR_VALUE("Enter applied temperature value", trans1_TT_2_Cal_Point_Lo);
            fValue = trans1_TT_2_Cal_Point_Lo;

            if (ret < 0)
            {
                process_abort();
            }

            WriteCommand (write_trans1_TT_2_Cal_Point_Lo);
            ReadCommand (read_trans1_TT_2_Cal_Point_Lo);
        }
        else
        {
            ACKNOWLEDGE("Function not permitted during simulation");  
        }

    }
}

METHOD method_set_trans1_TT_2_cal_point_hi
{
    LABEL        [MC_Start];
    DEFINITION
    {
        int ret,fValue;

        if (func1_AI_2_simulation_enabled == 0)        //0 = [off]
        {
            ret = GET_DEV_VAR_VALUE("Enter applied temperature value", trans1_TT_2_Cal_Point_Hi);
            fValue = trans1_TT_2_Cal_Point_Hi;

            if (ret < 0)
            {
                process_abort();
            }

            WriteCommand (write_trans1_TT_2_Cal_Point_Hi);
            ReadCommand (read_trans1_TT_2_Cal_Point_Hi);
        }
        else
        {
            ACKNOWLEDGE("Function not permitted during simulation");  
        }

    }
}
